/* YouTubePublishing.c generated by valac 0.40.4, the Vala compiler
 * generated from YouTubePublishing.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include "gdata/gdata.h"
#include <libsoup/soup.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include "shotwell-authenticator.h"
#include <gobject/gvaluecollector.h>


#define TYPE_YOU_TUBE_SERVICE (you_tube_service_get_type ())
#define YOU_TUBE_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_YOU_TUBE_SERVICE, YouTubeService))
#define YOU_TUBE_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_YOU_TUBE_SERVICE, YouTubeServiceClass))
#define IS_YOU_TUBE_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_YOU_TUBE_SERVICE))
#define IS_YOU_TUBE_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_YOU_TUBE_SERVICE))
#define YOU_TUBE_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_YOU_TUBE_SERVICE, YouTubeServiceClass))

typedef struct _YouTubeService YouTubeService;
typedef struct _YouTubeServiceClass YouTubeServiceClass;
typedef struct _YouTubeServicePrivate YouTubeServicePrivate;
enum  {
	YOU_TUBE_SERVICE_0_PROPERTY,
	YOU_TUBE_SERVICE_NUM_PROPERTIES
};
static GParamSpec* you_tube_service_properties[YOU_TUBE_SERVICE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER (publishing_you_tube_you_tube_publisher_get_type ())
#define PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher))
#define PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisherClass))
#define PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER))
#define PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER))
#define PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisherClass))

typedef struct _PublishingYouTubeYouTubePublisher PublishingYouTubeYouTubePublisher;
typedef struct _PublishingYouTubeYouTubePublisherClass PublishingYouTubeYouTubePublisherClass;

#define PUBLISHING_YOU_TUBE_TYPE_PRIVACY_SETTING (publishing_you_tube_privacy_setting_get_type ())

#define PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS (publishing_you_tube_publishing_parameters_get_type ())
#define PUBLISHING_YOU_TUBE_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS, PublishingYouTubePublishingParameters))
#define PUBLISHING_YOU_TUBE_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS, PublishingYouTubePublishingParametersClass))
#define PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_YOU_TUBE_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS, PublishingYouTubePublishingParametersClass))

typedef struct _PublishingYouTubePublishingParameters PublishingYouTubePublishingParameters;
typedef struct _PublishingYouTubePublishingParametersClass PublishingYouTubePublishingParametersClass;
typedef struct _PublishingYouTubePublishingParametersPrivate PublishingYouTubePublishingParametersPrivate;
typedef struct _PublishingYouTubeParamSpecPublishingParameters PublishingYouTubeParamSpecPublishingParameters;

#define PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER (publishing_you_tube_you_tube_authorizer_get_type ())
#define PUBLISHING_YOU_TUBE_YOU_TUBE_AUTHORIZER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, PublishingYouTubeYouTubeAuthorizer))
#define PUBLISHING_YOU_TUBE_YOU_TUBE_AUTHORIZER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, PublishingYouTubeYouTubeAuthorizerClass))
#define PUBLISHING_YOU_TUBE_IS_YOU_TUBE_AUTHORIZER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER))
#define PUBLISHING_YOU_TUBE_IS_YOU_TUBE_AUTHORIZER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER))
#define PUBLISHING_YOU_TUBE_YOU_TUBE_AUTHORIZER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, PublishingYouTubeYouTubeAuthorizerClass))

typedef struct _PublishingYouTubeYouTubeAuthorizer PublishingYouTubeYouTubeAuthorizer;
typedef struct _PublishingYouTubeYouTubeAuthorizerClass PublishingYouTubeYouTubeAuthorizerClass;
typedef struct _PublishingYouTubeYouTubeAuthorizerPrivate PublishingYouTubeYouTubeAuthorizerPrivate;
enum  {
	PUBLISHING_YOU_TUBE_YOU_TUBE_AUTHORIZER_0_PROPERTY,
	PUBLISHING_YOU_TUBE_YOU_TUBE_AUTHORIZER_NUM_PROPERTIES
};
static GParamSpec* publishing_you_tube_you_tube_authorizer_properties[PUBLISHING_YOU_TUBE_YOU_TUBE_AUTHORIZER_NUM_PROPERTIES];
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _PublishingYouTubeYouTubePublisherPrivate PublishingYouTubeYouTubePublisherPrivate;
enum  {
	PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_0_PROPERTY,
	PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_NUM_PROPERTIES
};
static GParamSpec* publishing_you_tube_you_tube_publisher_properties[PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_NUM_PROPERTIES];
#define _publishing_you_tube_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_you_tube_publishing_parameters_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE (publishing_you_tube_publishing_options_pane_get_type ())
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPane))
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPaneClass))
#define PUBLISHING_YOU_TUBE_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_YOU_TUBE_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPaneClass))

typedef struct _PublishingYouTubePublishingOptionsPane PublishingYouTubePublishingOptionsPane;
typedef struct _PublishingYouTubePublishingOptionsPaneClass PublishingYouTubePublishingOptionsPaneClass;

#define PUBLISHING_YOU_TUBE_TYPE_UPLOADER (publishing_you_tube_uploader_get_type ())
#define PUBLISHING_YOU_TUBE_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_YOU_TUBE_TYPE_UPLOADER, PublishingYouTubeUploader))
#define PUBLISHING_YOU_TUBE_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_YOU_TUBE_TYPE_UPLOADER, PublishingYouTubeUploaderClass))
#define PUBLISHING_YOU_TUBE_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_YOU_TUBE_TYPE_UPLOADER))
#define PUBLISHING_YOU_TUBE_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_YOU_TUBE_TYPE_UPLOADER))
#define PUBLISHING_YOU_TUBE_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_YOU_TUBE_TYPE_UPLOADER, PublishingYouTubeUploaderClass))

typedef struct _PublishingYouTubeUploader PublishingYouTubeUploader;
typedef struct _PublishingYouTubeUploaderClass PublishingYouTubeUploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
typedef struct _PublishingYouTubePublishingOptionsPanePrivate PublishingYouTubePublishingOptionsPanePrivate;

#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION (publishing_you_tube_publishing_options_pane_privacy_description_get_type ())
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, PublishingYouTubePublishingOptionsPanePrivacyDescription))
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, PublishingYouTubePublishingOptionsPanePrivacyDescriptionClass))
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_IS_PRIVACY_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION))
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_IS_PRIVACY_DESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION))
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, PublishingYouTubePublishingOptionsPanePrivacyDescriptionClass))

typedef struct _PublishingYouTubePublishingOptionsPanePrivacyDescription PublishingYouTubePublishingOptionsPanePrivacyDescription;
typedef struct _PublishingYouTubePublishingOptionsPanePrivacyDescriptionClass PublishingYouTubePublishingOptionsPanePrivacyDescriptionClass;
enum  {
	PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_0_PROPERTY,
	PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_NUM_PROPERTIES
};
static GParamSpec* publishing_you_tube_publishing_options_pane_properties[PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_NUM_PROPERTIES];
#define _g_slist_free0(var) ((var == NULL) ? NULL : (var = (g_slist_free (var), NULL)))
typedef struct _PublishingYouTubePublishingOptionsPanePrivacyDescriptionPrivate PublishingYouTubePublishingOptionsPanePrivacyDescriptionPrivate;
#define _publishing_you_tube_publishing_options_pane_privacy_description_unref0(var) ((var == NULL) ? NULL : (var = (publishing_you_tube_publishing_options_pane_privacy_description_unref (var), NULL)))
typedef struct _PublishingYouTubePublishingOptionsPaneParamSpecPrivacyDescription PublishingYouTubePublishingOptionsPaneParamSpecPrivacyDescription;
enum  {
	PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL,
	PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL,
	PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_NUM_SIGNALS
};
static guint publishing_you_tube_publishing_options_pane_signals[PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_NUM_SIGNALS] = {0};

#define PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION (publishing_you_tube_upload_transaction_get_type ())
#define PUBLISHING_YOU_TUBE_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION, PublishingYouTubeUploadTransaction))
#define PUBLISHING_YOU_TUBE_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION, PublishingYouTubeUploadTransactionClass))
#define PUBLISHING_YOU_TUBE_IS_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_YOU_TUBE_IS_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_YOU_TUBE_UPLOAD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION, PublishingYouTubeUploadTransactionClass))

typedef struct _PublishingYouTubeUploadTransaction PublishingYouTubeUploadTransaction;
typedef struct _PublishingYouTubeUploadTransactionClass PublishingYouTubeUploadTransactionClass;
typedef struct _PublishingYouTubeUploadTransactionPrivate PublishingYouTubeUploadTransactionPrivate;
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
typedef struct _PublishingYouTubeUploadTransactionSpliceWithProgressData PublishingYouTubeUploadTransactionSpliceWithProgressData;
typedef struct _PublishingYouTubeUploaderPrivate PublishingYouTubeUploaderPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _YouTubeService {
	GObject parent_instance;
	YouTubeServicePrivate * priv;
};

struct _YouTubeServiceClass {
	GObjectClass parent_class;
};

typedef enum  {
	PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PUBLIC,
	PUBLISHING_YOU_TUBE_PRIVACY_SETTING_UNLISTED,
	PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PRIVATE
} PublishingYouTubePrivacySetting;

struct _PublishingYouTubePublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingYouTubePublishingParametersPrivate * priv;
};

struct _PublishingYouTubePublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingYouTubePublishingParameters *self);
};

struct _PublishingYouTubePublishingParametersPrivate {
	PublishingYouTubePrivacySetting privacy;
	gchar* user_name;
};

struct _PublishingYouTubeParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingYouTubeYouTubeAuthorizer {
	GObject parent_instance;
	PublishingYouTubeYouTubeAuthorizerPrivate * priv;
};

struct _PublishingYouTubeYouTubeAuthorizerClass {
	GObjectClass parent_class;
};

struct _PublishingYouTubeYouTubeAuthorizerPrivate {
	PublishingRESTSupportGoogleSession* session;
	SpitPublishingAuthenticator* authenticator;
};

struct _PublishingYouTubeYouTubePublisher {
	PublishingRESTSupportGooglePublisher parent_instance;
	PublishingYouTubeYouTubePublisherPrivate * priv;
};

struct _PublishingYouTubeYouTubePublisherClass {
	PublishingRESTSupportGooglePublisherClass parent_class;
};

struct _PublishingYouTubeYouTubePublisherPrivate {
	gboolean running;
	PublishingYouTubePublishingParameters* publishing_parameters;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	SpitPublishingAuthenticator* authenticator;
	GDataYouTubeService* youtube_service;
};

struct _PublishingYouTubePublishingOptionsPane {
	GObject parent_instance;
	PublishingYouTubePublishingOptionsPanePrivate * priv;
};

struct _PublishingYouTubePublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingYouTubePublishingOptionsPanePrivate {
	GtkBox* pane_widget;
	GtkComboBoxText* privacy_combo;
	GtkLabel* login_identity_label;
	GtkButton* publish_button;
	GtkButton* logout_button;
	GtkBuilder* builder;
	GtkLabel* privacy_label;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** privacy_descriptions;
	gint privacy_descriptions_length1;
	gint _privacy_descriptions_size_;
	PublishingYouTubePublishingParameters* publishing_parameters;
};

struct _PublishingYouTubePublishingOptionsPanePrivacyDescription {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingYouTubePublishingOptionsPanePrivacyDescriptionPrivate * priv;
	gchar* description;
	PublishingYouTubePrivacySetting privacy_setting;
};

struct _PublishingYouTubePublishingOptionsPanePrivacyDescriptionClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingYouTubePublishingOptionsPanePrivacyDescription *self);
};

struct _PublishingYouTubePublishingOptionsPaneParamSpecPrivacyDescription {
	GParamSpec parent_instance;
};

struct _PublishingYouTubeUploadTransaction {
	PublishingRESTSupportGooglePublisherAuthenticatedTransaction parent_instance;
	PublishingYouTubeUploadTransactionPrivate * priv;
};

struct _PublishingYouTubeUploadTransactionClass {
	PublishingRESTSupportGooglePublisherAuthenticatedTransactionClass parent_class;
};

struct _PublishingYouTubeUploadTransactionPrivate {
	PublishingYouTubePublishingParameters* parameters;
	PublishingRESTSupportGoogleSession* session;
	SpitPublishingPublishable* publishable;
	GDataYouTubeService* youtube_service;
};

struct _Block1Data {
	int _ref_count_;
	PublishingYouTubeUploadTransaction* self;
	GMainLoop* loop;
};

struct _PublishingYouTubeUploadTransactionSpliceWithProgressData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	PublishingYouTubeUploadTransaction* self;
	GFileInfo* info;
	GInputStream* input;
	GOutputStream* output;
	gint64 total_bytes;
	gint64 bytes_to_write;
	gint64 _tmp0_;
	guint8 buffer[8192];
	gint64 _tmp1_;
	gssize bytes_read;
	gssize _tmp2_;
	gssize bytes_written;
	gssize _tmp3_;
	gint64 _tmp4_;
	gssize _tmp5_;
	gint64 _tmp6_;
	gint64 _tmp7_;
	gint64 _tmp8_;
	GError * _inner_error_;
};

struct _PublishingYouTubeUploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingYouTubeUploaderPrivate * priv;
};

struct _PublishingYouTubeUploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingYouTubeUploaderPrivate {
	PublishingYouTubePublishingParameters* parameters;
	GDataYouTubeService* youtube_service;
};


static gpointer you_tube_service_parent_class = NULL;
static GdkPixbuf** you_tube_service_icon_pixbuf_set;
static gint you_tube_service_icon_pixbuf_set_length1;
static GdkPixbuf** you_tube_service_icon_pixbuf_set = NULL;
static gint you_tube_service_icon_pixbuf_set_length1 = 0;
static gint _you_tube_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface * you_tube_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface * you_tube_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_you_tube_publishing_parameters_parent_class = NULL;
static gpointer publishing_you_tube_you_tube_authorizer_parent_class = NULL;
static GDataAuthorizerInterface * publishing_you_tube_you_tube_authorizer_gdata_authorizer_parent_iface = NULL;
static gpointer publishing_you_tube_you_tube_publisher_parent_class = NULL;
static gpointer publishing_you_tube_publishing_options_pane_parent_class = NULL;
static gpointer publishing_you_tube_publishing_options_pane_privacy_description_parent_class = NULL;
static SpitPublishingDialogPaneIface * publishing_you_tube_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_you_tube_upload_transaction_parent_class = NULL;
static gpointer publishing_you_tube_uploader_parent_class = NULL;

GType you_tube_service_get_type (void) G_GNUC_CONST;
#define YOU_TUBE_SERVICE_ICON_FILENAME "youtube.png"
YouTubeService* you_tube_service_new (GFile* resource_directory);
YouTubeService* you_tube_service_construct (GType object_type,
                                            GFile* resource_directory);
static gint you_tube_service_real_get_pluggable_interface (SpitPluggable* base,
                                                    gint min_host_interface,
                                                    gint max_host_interface);
static const gchar* you_tube_service_real_get_id (SpitPluggable* base);
static const gchar* you_tube_service_real_get_pluggable_name (SpitPluggable* base);
static void you_tube_service_real_get_info (SpitPluggable* base,
                                     SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup11 (GdkPixbuf** self,
                               int length);
static SpitPublishingPublisher* you_tube_service_real_create_publisher (SpitPublishingService* base,
                                                                 SpitPublishingPluginHost* host);
PublishingYouTubeYouTubePublisher* publishing_you_tube_you_tube_publisher_new (SpitPublishingService* service,
                                                                               SpitPublishingPluginHost* host);
PublishingYouTubeYouTubePublisher* publishing_you_tube_you_tube_publisher_construct (GType object_type,
                                                                                     SpitPublishingService* service,
                                                                                     SpitPublishingPluginHost* host);
GType publishing_you_tube_you_tube_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType you_tube_service_real_get_supported_media (SpitPublishingService* base);
static void you_tube_service_real_activation (SpitPluggable* base,
                                       gboolean enabled);
static void you_tube_service_finalize (GObject * obj);
#define PUBLISHING_YOU_TUBE_DEVELOPER_KEY "AIzaSyB6hLnm0n5j8Y6Bkvh9bz3i8ADM2bJdYeY"
GType publishing_you_tube_privacy_setting_get_type (void) G_GNUC_CONST;
gpointer publishing_you_tube_publishing_parameters_ref (gpointer instance);
void publishing_you_tube_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_you_tube_param_spec_publishing_parameters (const gchar* name,
                                                                  const gchar* nick,
                                                                  const gchar* blurb,
                                                                  GType object_type,
                                                                  GParamFlags flags);
void publishing_you_tube_value_set_publishing_parameters (GValue* value,
                                                          gpointer v_object);
void publishing_you_tube_value_take_publishing_parameters (GValue* value,
                                                           gpointer v_object);
gpointer publishing_you_tube_value_get_publishing_parameters (const GValue* value);
GType publishing_you_tube_publishing_parameters_get_type (void) G_GNUC_CONST;
#define PUBLISHING_YOU_TUBE_PUBLISHING_PARAMETERS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS, PublishingYouTubePublishingParametersPrivate))
PublishingYouTubePublishingParameters* publishing_you_tube_publishing_parameters_new (void);
PublishingYouTubePublishingParameters* publishing_you_tube_publishing_parameters_construct (GType object_type);
PublishingYouTubePrivacySetting publishing_you_tube_publishing_parameters_get_privacy (PublishingYouTubePublishingParameters* self);
void publishing_you_tube_publishing_parameters_set_privacy (PublishingYouTubePublishingParameters* self,
                                                            PublishingYouTubePrivacySetting privacy);
gchar* publishing_you_tube_publishing_parameters_get_user_name (PublishingYouTubePublishingParameters* self);
void publishing_you_tube_publishing_parameters_set_user_name (PublishingYouTubePublishingParameters* self,
                                                              const gchar* user_name);
static void publishing_you_tube_publishing_parameters_finalize (PublishingYouTubePublishingParameters * obj);
GType publishing_you_tube_you_tube_authorizer_get_type (void) G_GNUC_CONST;
#define PUBLISHING_YOU_TUBE_YOU_TUBE_AUTHORIZER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, PublishingYouTubeYouTubeAuthorizerPrivate))
PublishingYouTubeYouTubeAuthorizer* publishing_you_tube_you_tube_authorizer_new (PublishingRESTSupportGoogleSession* session,
                                                                                 SpitPublishingAuthenticator* authenticator);
PublishingYouTubeYouTubeAuthorizer* publishing_you_tube_you_tube_authorizer_construct (GType object_type,
                                                                                       PublishingRESTSupportGoogleSession* session,
                                                                                       SpitPublishingAuthenticator* authenticator);
static gboolean publishing_you_tube_you_tube_authorizer_real_is_authorized_for_domain (GDataAuthorizer* base,
                                                                                GDataAuthorizationDomain* domain);
static void publishing_you_tube_you_tube_authorizer_real_process_request (GDataAuthorizer* base,
                                                                   GDataAuthorizationDomain* domain,
                                                                   SoupMessage* message);
static gboolean publishing_you_tube_you_tube_authorizer_real_refresh_authorization (GDataAuthorizer* base,
                                                                             GCancellable* cancellable,
                                                                             GError** error);
static void publishing_you_tube_you_tube_authorizer_finalize (GObject * obj);
#define PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisherPrivate))
static gboolean publishing_you_tube_you_tube_publisher_real_is_running (PublishingRESTSupportGooglePublisher* base);
static void publishing_you_tube_you_tube_publisher_real_start (PublishingRESTSupportGooglePublisher* base);
static void publishing_you_tube_you_tube_publisher_real_stop (PublishingRESTSupportGooglePublisher* base);
static void publishing_you_tube_you_tube_publisher_real_on_login_flow_complete (PublishingRESTSupportGooglePublisher* base);
static void publishing_you_tube_you_tube_publisher_do_show_publishing_options_pane (PublishingYouTubeYouTubePublisher* self);
static void publishing_you_tube_you_tube_publisher_on_publishing_options_logout (PublishingYouTubeYouTubePublisher* self);
static void publishing_you_tube_you_tube_publisher_on_publishing_options_publish (PublishingYouTubeYouTubePublisher* self);
static void publishing_you_tube_you_tube_publisher_do_upload (PublishingYouTubeYouTubePublisher* self);
static void publishing_you_tube_you_tube_publisher_on_upload_status_updated (PublishingYouTubeYouTubePublisher* self,
                                                                      gint file_number,
                                                                      gdouble completed_fraction);
static void publishing_you_tube_you_tube_publisher_on_upload_complete (PublishingYouTubeYouTubePublisher* self,
                                                                PublishingRESTSupportBatchUploader* uploader,
                                                                gint num_published);
static void _publishing_you_tube_you_tube_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                        gint num_photos_published,
                                                                                                                        gpointer self);
static void publishing_you_tube_you_tube_publisher_on_upload_error (PublishingYouTubeYouTubePublisher* self,
                                                             PublishingRESTSupportBatchUploader* uploader,
                                                             GError* err);
static void _publishing_you_tube_you_tube_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                  GError* err,
                                                                                                                  gpointer self);
static void publishing_you_tube_you_tube_publisher_do_show_success_pane (PublishingYouTubeYouTubePublisher* self);
GType publishing_you_tube_publishing_options_pane_get_type (void) G_GNUC_CONST;
PublishingYouTubePublishingOptionsPane* publishing_you_tube_publishing_options_pane_new (SpitPublishingAuthenticator* authenticator,
                                                                                         SpitPublishingPluginHost* host,
                                                                                         GtkBuilder* builder,
                                                                                         PublishingYouTubePublishingParameters* publishing_parameters);
PublishingYouTubePublishingOptionsPane* publishing_you_tube_publishing_options_pane_construct (GType object_type,
                                                                                               SpitPublishingAuthenticator* authenticator,
                                                                                               SpitPublishingPluginHost* host,
                                                                                               GtkBuilder* builder,
                                                                                               PublishingYouTubePublishingParameters* publishing_parameters);
static void _publishing_you_tube_you_tube_publisher_on_publishing_options_publish_publishing_you_tube_publishing_options_pane_publish (PublishingYouTubePublishingOptionsPane* _sender,
                                                                                                                                gpointer self);
static void _publishing_you_tube_you_tube_publisher_on_publishing_options_logout_publishing_you_tube_publishing_options_pane_logout (PublishingYouTubePublishingOptionsPane* _sender,
                                                                                                                              gpointer self);
GType publishing_you_tube_uploader_get_type (void) G_GNUC_CONST;
PublishingYouTubeUploader* publishing_you_tube_uploader_new (GDataYouTubeService* youtube_service,
                                                             PublishingRESTSupportGoogleSession* session,
                                                             SpitPublishingPublishable** publishables,
                                                             int publishables_length1,
                                                             PublishingYouTubePublishingParameters* parameters);
PublishingYouTubeUploader* publishing_you_tube_uploader_construct (GType object_type,
                                                                   GDataYouTubeService* youtube_service,
                                                                   PublishingRESTSupportGoogleSession* session,
                                                                   SpitPublishingPublishable** publishables,
                                                                   int publishables_length1,
                                                                   PublishingYouTubePublishingParameters* parameters);
static void _publishing_you_tube_you_tube_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number,
                                                                                                         gdouble fraction_complete,
                                                                                                         gpointer self);
static void publishing_you_tube_you_tube_publisher_real_do_logout (PublishingRESTSupportGooglePublisher* base);
static SpitPublishingAuthenticator* publishing_you_tube_you_tube_publisher_real_get_authenticator (PublishingRESTSupportGooglePublisher* base);
static void publishing_you_tube_you_tube_publisher_finalize (GObject * obj);
static gpointer publishing_you_tube_publishing_options_pane_privacy_description_ref (gpointer instance);
static void publishing_you_tube_publishing_options_pane_privacy_description_unref (gpointer instance);
static GParamSpec* publishing_you_tube_publishing_options_pane_param_spec_privacy_description (const gchar* name,
                                                                                        const gchar* nick,
                                                                                        const gchar* blurb,
                                                                                        GType object_type,
                                                                                        GParamFlags flags) G_GNUC_UNUSED;
static void publishing_you_tube_publishing_options_pane_value_set_privacy_description (GValue* value,
                                                                                gpointer v_object) G_GNUC_UNUSED;
static void publishing_you_tube_publishing_options_pane_value_take_privacy_description (GValue* value,
                                                                                 gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_you_tube_publishing_options_pane_value_get_privacy_description (const GValue* value) G_GNUC_UNUSED;
static GType publishing_you_tube_publishing_options_pane_privacy_description_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPanePrivate))
static PublishingYouTubePublishingOptionsPanePrivacyDescription** publishing_you_tube_publishing_options_pane_create_privacy_descriptions (PublishingYouTubePublishingOptionsPane* self,
                                                                                                                                    int* result_length1);
static void publishing_you_tube_publishing_options_pane_on_logout_clicked (PublishingYouTubePublishingOptionsPane* self);
static void _publishing_you_tube_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                        gpointer self);
static void publishing_you_tube_publishing_options_pane_on_publish_clicked (PublishingYouTubePublishingOptionsPane* self);
static void _publishing_you_tube_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                         gpointer self);
static void publishing_you_tube_publishing_options_pane_update_publish_button_sensitivity (PublishingYouTubePublishingOptionsPane* self);
static PublishingYouTubePublishingOptionsPanePrivacyDescription* publishing_you_tube_publishing_options_pane_privacy_description_new (const gchar* description,
                                                                                                                               PublishingYouTubePrivacySetting privacy_setting);
static PublishingYouTubePublishingOptionsPanePrivacyDescription* publishing_you_tube_publishing_options_pane_privacy_description_construct (GType object_type,
                                                                                                                                     const gchar* description,
                                                                                                                                     PublishingYouTubePrivacySetting privacy_setting);
static void _vala_array_add35 (PublishingYouTubePublishingOptionsPanePrivacyDescription** * array,
                        int* length,
                        int* size,
                        PublishingYouTubePublishingOptionsPanePrivacyDescription* value);
static void _vala_array_add36 (PublishingYouTubePublishingOptionsPanePrivacyDescription** * array,
                        int* length,
                        int* size,
                        PublishingYouTubePublishingOptionsPanePrivacyDescription* value);
static void _vala_array_add37 (PublishingYouTubePublishingOptionsPanePrivacyDescription** * array,
                        int* length,
                        int* size,
                        PublishingYouTubePublishingOptionsPanePrivacyDescription* value);
static GtkWidget* publishing_you_tube_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_you_tube_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_you_tube_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_you_tube_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void publishing_you_tube_publishing_options_pane_privacy_description_finalize (PublishingYouTubePublishingOptionsPanePrivacyDescription * obj);
static void publishing_you_tube_publishing_options_pane_finalize (GObject * obj);
GType publishing_you_tube_upload_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_YOU_TUBE_UPLOAD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION, PublishingYouTubeUploadTransactionPrivate))
#define PUBLISHING_YOU_TUBE_UPLOAD_TRANSACTION_ENDPOINT_URL "https://uploads.gdata.youtube.com/feeds/api/users/default/uploads"
PublishingYouTubeUploadTransaction* publishing_you_tube_upload_transaction_new (GDataYouTubeService* youtube_service,
                                                                                PublishingRESTSupportGoogleSession* session,
                                                                                PublishingYouTubePublishingParameters* parameters,
                                                                                SpitPublishingPublishable* publishable);
PublishingYouTubeUploadTransaction* publishing_you_tube_upload_transaction_construct (GType object_type,
                                                                                      GDataYouTubeService* youtube_service,
                                                                                      PublishingRESTSupportGoogleSession* session,
                                                                                      PublishingYouTubePublishingParameters* parameters,
                                                                                      SpitPublishingPublishable* publishable);
static void publishing_you_tube_upload_transaction_real_execute (PublishingRESTSupportTransaction* base,
                                                          GError** error);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void publishing_you_tube_upload_transaction_splice_with_progress (PublishingYouTubeUploadTransaction* self,
                                                                  GFileInfo* info,
                                                                  GInputStream* input,
                                                                  GOutputStream* output,
                                                                  GAsyncReadyCallback _callback_,
                                                                  gpointer _user_data_);
static void publishing_you_tube_upload_transaction_splice_with_progress_finish (PublishingYouTubeUploadTransaction* self,
                                                                         GAsyncResult* _res_,
                                                                         GError** error);
static void ___lambda4_ (Block1Data* _data1_,
                  GObject* obj,
                  GAsyncResult* res);
static void ____lambda4__gasync_ready_callback (GObject* source_object,
                                         GAsyncResult* res,
                                         gpointer self);
static void publishing_you_tube_upload_transaction_splice_with_progress_data_free (gpointer _data);
static void publishing_you_tube_upload_transaction_splice_with_progress_async_ready_wrapper (GObject *source_object,
                                                                                      GAsyncResult *res,
                                                                                      void *user_data);
static gboolean publishing_you_tube_upload_transaction_splice_with_progress_co (PublishingYouTubeUploadTransactionSpliceWithProgressData* _data_);
static void publishing_you_tube_upload_transaction_splice_with_progress_ready (GObject* source_object,
                                                                        GAsyncResult* _res_,
                                                                        gpointer _user_data_);
static void publishing_you_tube_upload_transaction_finalize (PublishingRESTSupportTransaction * obj);
#define PUBLISHING_YOU_TUBE_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_YOU_TUBE_TYPE_UPLOADER, PublishingYouTubeUploaderPrivate))
static PublishingRESTSupportTransaction* publishing_you_tube_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base,
                                                                                        SpitPublishingPublishable* publishable);
static void publishing_you_tube_uploader_finalize (PublishingRESTSupportBatchUploader * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);


YouTubeService*
you_tube_service_construct (GType object_type,
                            GFile* resource_directory)
{
	YouTubeService * self = NULL;
	GdkPixbuf** _tmp0_;
	gint _tmp0__length1;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = (YouTubeService*) g_object_new (object_type, NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = you_tube_service_icon_pixbuf_set;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0__length1 = you_tube_service_icon_pixbuf_set_length1;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (_tmp0_ == NULL) {
#line 594 "YouTubePublishing.c"
		gint _tmp1_;
		GdkPixbuf** _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" YOU_TUBE_SERVICE_ICON_FILENAME, &_tmp1_);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		you_tube_service_icon_pixbuf_set = (_vala_array_free (you_tube_service_icon_pixbuf_set, you_tube_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		you_tube_service_icon_pixbuf_set = _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		you_tube_service_icon_pixbuf_set_length1 = _tmp1_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_you_tube_service_icon_pixbuf_set_size_ = you_tube_service_icon_pixbuf_set_length1;
#line 607 "YouTubePublishing.c"
	}
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self;
#line 611 "YouTubePublishing.c"
}


YouTubeService*
you_tube_service_new (GFile* resource_directory)
{
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return you_tube_service_construct (TYPE_YOU_TUBE_SERVICE, resource_directory);
#line 620 "YouTubePublishing.c"
}


static gint
you_tube_service_real_get_pluggable_interface (SpitPluggable* base,
                                               gint min_host_interface,
                                               gint max_host_interface)
{
	YouTubeService * self;
	gint result = 0;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_YOU_TUBE_SERVICE, YouTubeService);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = spit_negotiate_interfaces (min_host_interface, max_host_interface, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 637 "YouTubePublishing.c"
}


static const gchar*
you_tube_service_real_get_id (SpitPluggable* base)
{
	YouTubeService * self;
	const gchar* result = NULL;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_YOU_TUBE_SERVICE, YouTubeService);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = "org.yorba.shotwell.publishing.youtube";
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 652 "YouTubePublishing.c"
}


static const gchar*
you_tube_service_real_get_pluggable_name (SpitPluggable* base)
{
	YouTubeService * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_YOU_TUBE_SERVICE, YouTubeService);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = "YouTube";
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 667 "YouTubePublishing.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 676 "YouTubePublishing.c"
}


static GdkPixbuf**
_vala_array_dup11 (GdkPixbuf** self,
                   int length)
{
	GdkPixbuf** result;
	int i;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	for (i = 0; i < length; i++) {
#line 690 "YouTubePublishing.c"
		GdkPixbuf* _tmp0_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		result[i] = _tmp0_;
#line 696 "YouTubePublishing.c"
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 700 "YouTubePublishing.c"
}


static void
you_tube_service_real_get_info (SpitPluggable* base,
                                SpitPluggableInfo* info)
{
	YouTubeService * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GdkPixbuf** _tmp7_;
	gint _tmp7__length1;
	GdkPixbuf** _tmp8_;
	gint _tmp8__length1;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_YOU_TUBE_SERVICE, YouTubeService);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (info != NULL);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = g_strdup ("Jani Monoses, Lucas Beeler");
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 ((*info).authors);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).authors = _tmp0_;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = g_strdup (_ ("Copyright 2016 Software Freedom Conservancy Inc."));
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 ((*info).copyright);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).copyright = _tmp1_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 ((*info).translators);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).translators = _tmp2_;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = g_strdup (_VERSION);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 ((*info).version);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).version = _tmp3_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp4_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 ((*info).website_name);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).website_name = _tmp4_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 ((*info).website_url);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).website_url = _tmp5_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_LICENSE);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 ((*info).license);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).license = _tmp6_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp7_ = you_tube_service_icon_pixbuf_set;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp7__length1 = you_tube_service_icon_pixbuf_set_length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp8_ = (_tmp7_ != NULL) ? _vala_array_dup11 (_tmp7_, _tmp7__length1) : ((gpointer) _tmp7_);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp8__length1 = _tmp7__length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).icons = _tmp8_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*info).icons_length1 = _tmp8__length1;
#line 782 "YouTubePublishing.c"
}


static SpitPublishingPublisher*
you_tube_service_real_create_publisher (SpitPublishingService* base,
                                        SpitPublishingPluginHost* host)
{
	YouTubeService * self;
	SpitPublishingPublisher* result = NULL;
	PublishingYouTubeYouTubePublisher* _tmp0_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_YOU_TUBE_SERVICE, YouTubeService);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = publishing_you_tube_you_tube_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), host);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 803 "YouTubePublishing.c"
}


static SpitPublishingPublisherMediaType
you_tube_service_real_get_supported_media (SpitPublishingService* base)
{
	YouTubeService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_YOU_TUBE_SERVICE, YouTubeService);
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 818 "YouTubePublishing.c"
}


static void
you_tube_service_real_activation (SpitPluggable* base,
                                  gboolean enabled)
{
	YouTubeService * self;
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_YOU_TUBE_SERVICE, YouTubeService);
#line 829 "YouTubePublishing.c"
}


static void
you_tube_service_class_init (YouTubeServiceClass * klass)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	you_tube_service_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = you_tube_service_finalize;
#line 840 "YouTubePublishing.c"
}


static void
you_tube_service_spit_pluggable_interface_init (SpitPluggableIface * iface)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	you_tube_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->get_pluggable_interface = (gint (*) (SpitPluggable *, gint, gint)) you_tube_service_real_get_pluggable_interface;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->get_id = (const gchar* (*) (SpitPluggable *)) you_tube_service_real_get_id;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->get_pluggable_name = (const gchar* (*) (SpitPluggable *)) you_tube_service_real_get_pluggable_name;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->get_info = (void (*) (SpitPluggable *, SpitPluggableInfo*)) you_tube_service_real_get_info;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->activation = (void (*) (SpitPluggable *, gboolean)) you_tube_service_real_activation;
#line 859 "YouTubePublishing.c"
}


static void
you_tube_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	you_tube_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*) (SpitPublishingService *, SpitPublishingPluginHost*)) you_tube_service_real_create_publisher;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*) (SpitPublishingService *)) you_tube_service_real_get_supported_media;
#line 872 "YouTubePublishing.c"
}


static void
you_tube_service_instance_init (YouTubeService * self)
{
}


static void
you_tube_service_finalize (GObject * obj)
{
	YouTubeService * self;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_YOU_TUBE_SERVICE, YouTubeService);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_OBJECT_CLASS (you_tube_service_parent_class)->finalize (obj);
#line 890 "YouTubePublishing.c"
}


GType
you_tube_service_get_type (void)
{
	static volatile gsize you_tube_service_type_id__volatile = 0;
	if (g_once_init_enter (&you_tube_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (YouTubeServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) you_tube_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (YouTubeService), 0, (GInstanceInitFunc) you_tube_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) you_tube_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) you_tube_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType you_tube_service_type_id;
		you_tube_service_type_id = g_type_register_static (G_TYPE_OBJECT, "YouTubeService", &g_define_type_info, 0);
		g_type_add_interface_static (you_tube_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (you_tube_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&you_tube_service_type_id__volatile, you_tube_service_type_id);
	}
	return you_tube_service_type_id__volatile;
}


GType
publishing_you_tube_privacy_setting_get_type (void)
{
	static volatile gsize publishing_you_tube_privacy_setting_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_you_tube_privacy_setting_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PUBLIC, "PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PUBLIC", "public"}, {PUBLISHING_YOU_TUBE_PRIVACY_SETTING_UNLISTED, "PUBLISHING_YOU_TUBE_PRIVACY_SETTING_UNLISTED", "unlisted"}, {PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PRIVATE, "PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PRIVATE", "private"}, {0, NULL, NULL}};
		GType publishing_you_tube_privacy_setting_type_id;
		publishing_you_tube_privacy_setting_type_id = g_enum_register_static ("PublishingYouTubePrivacySetting", values);
		g_once_init_leave (&publishing_you_tube_privacy_setting_type_id__volatile, publishing_you_tube_privacy_setting_type_id);
	}
	return publishing_you_tube_privacy_setting_type_id__volatile;
}


PublishingYouTubePublishingParameters*
publishing_you_tube_publishing_parameters_construct (GType object_type)
{
	PublishingYouTubePublishingParameters* self = NULL;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = (PublishingYouTubePublishingParameters*) g_type_create_instance (object_type);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy = PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PRIVATE;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (self->priv->user_name);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->user_name = NULL;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self;
#line 940 "YouTubePublishing.c"
}


PublishingYouTubePublishingParameters*
publishing_you_tube_publishing_parameters_new (void)
{
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return publishing_you_tube_publishing_parameters_construct (PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS);
#line 949 "YouTubePublishing.c"
}


PublishingYouTubePrivacySetting
publishing_you_tube_publishing_parameters_get_privacy (PublishingYouTubePublishingParameters* self)
{
	PublishingYouTubePrivacySetting result = 0;
	PublishingYouTubePrivacySetting _tmp0_;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS (self), 0);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->privacy;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = _tmp0_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 966 "YouTubePublishing.c"
}


void
publishing_you_tube_publishing_parameters_set_privacy (PublishingYouTubePublishingParameters* self,
                                                       PublishingYouTubePrivacySetting privacy)
{
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS (self));
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy = privacy;
#line 978 "YouTubePublishing.c"
}


gchar*
publishing_you_tube_publishing_parameters_get_user_name (PublishingYouTubePublishingParameters* self)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->user_name;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = _tmp1_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 998 "YouTubePublishing.c"
}


void
publishing_you_tube_publishing_parameters_set_user_name (PublishingYouTubePublishingParameters* self,
                                                         const gchar* user_name)
{
	gchar* _tmp0_;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS (self));
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = g_strdup (user_name);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (self->priv->user_name);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->user_name = _tmp0_;
#line 1015 "YouTubePublishing.c"
}


static void
publishing_you_tube_value_publishing_parameters_init (GValue* value)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1024 "YouTubePublishing.c"
}


static void
publishing_you_tube_value_publishing_parameters_free_value (GValue* value)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (value->data[0].v_pointer) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_publishing_parameters_unref (value->data[0].v_pointer);
#line 1035 "YouTubePublishing.c"
	}
}


static void
publishing_you_tube_value_publishing_parameters_copy_value (const GValue* src_value,
                                                            GValue* dest_value)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		dest_value->data[0].v_pointer = publishing_you_tube_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 1048 "YouTubePublishing.c"
	} else {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1052 "YouTubePublishing.c"
	}
}


static gpointer
publishing_you_tube_value_publishing_parameters_peek_pointer (const GValue* value)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return value->data[0].v_pointer;
#line 1062 "YouTubePublishing.c"
}


static gchar*
publishing_you_tube_value_publishing_parameters_collect_value (GValue* value,
                                                               guint n_collect_values,
                                                               GTypeCValue* collect_values,
                                                               guint collect_flags)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1074 "YouTubePublishing.c"
		PublishingYouTubePublishingParameters * object;
		object = collect_values[0].v_pointer;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1081 "YouTubePublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1085 "YouTubePublishing.c"
		}
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = publishing_you_tube_publishing_parameters_ref (object);
#line 1089 "YouTubePublishing.c"
	} else {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1093 "YouTubePublishing.c"
	}
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return NULL;
#line 1097 "YouTubePublishing.c"
}


static gchar*
publishing_you_tube_value_publishing_parameters_lcopy_value (const GValue* value,
                                                             guint n_collect_values,
                                                             GTypeCValue* collect_values,
                                                             guint collect_flags)
{
	PublishingYouTubePublishingParameters ** object_p;
	object_p = collect_values[0].v_pointer;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!object_p) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1113 "YouTubePublishing.c"
	}
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!value->data[0].v_pointer) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*object_p = NULL;
#line 1119 "YouTubePublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1123 "YouTubePublishing.c"
	} else {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*object_p = publishing_you_tube_publishing_parameters_ref (value->data[0].v_pointer);
#line 1127 "YouTubePublishing.c"
	}
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return NULL;
#line 1131 "YouTubePublishing.c"
}


GParamSpec*
publishing_you_tube_param_spec_publishing_parameters (const gchar* name,
                                                      const gchar* nick,
                                                      const gchar* blurb,
                                                      GType object_type,
                                                      GParamFlags flags)
{
	PublishingYouTubeParamSpecPublishingParameters* spec;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1151 "YouTubePublishing.c"
}


gpointer
publishing_you_tube_value_get_publishing_parameters (const GValue* value)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return value->data[0].v_pointer;
#line 1162 "YouTubePublishing.c"
}


void
publishing_you_tube_value_set_publishing_parameters (GValue* value,
                                                     gpointer v_object)
{
	PublishingYouTubePublishingParameters * old;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS));
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	old = value->data[0].v_pointer;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (v_object) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS));
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_publishing_parameters_ref (value->data[0].v_pointer);
#line 1185 "YouTubePublishing.c"
	} else {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1189 "YouTubePublishing.c"
	}
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (old) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_publishing_parameters_unref (old);
#line 1195 "YouTubePublishing.c"
	}
}


void
publishing_you_tube_value_take_publishing_parameters (GValue* value,
                                                      gpointer v_object)
{
	PublishingYouTubePublishingParameters * old;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS));
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	old = value->data[0].v_pointer;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (v_object) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS));
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1217 "YouTubePublishing.c"
	} else {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1221 "YouTubePublishing.c"
	}
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (old) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_publishing_parameters_unref (old);
#line 1227 "YouTubePublishing.c"
	}
}


static void
publishing_you_tube_publishing_parameters_class_init (PublishingYouTubePublishingParametersClass * klass)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingYouTubePublishingParametersClass *) klass)->finalize = publishing_you_tube_publishing_parameters_finalize;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingYouTubePublishingParametersPrivate));
#line 1241 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_parameters_instance_init (PublishingYouTubePublishingParameters * self)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv = PUBLISHING_YOU_TUBE_PUBLISHING_PARAMETERS_GET_PRIVATE (self);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->ref_count = 1;
#line 1252 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_parameters_finalize (PublishingYouTubePublishingParameters * obj)
{
	PublishingYouTubePublishingParameters * self;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_PARAMETERS, PublishingYouTubePublishingParameters);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_handlers_destroy (self);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (self->priv->user_name);
#line 1266 "YouTubePublishing.c"
}


GType
publishing_you_tube_publishing_parameters_get_type (void)
{
	static volatile gsize publishing_you_tube_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_you_tube_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_you_tube_value_publishing_parameters_init, publishing_you_tube_value_publishing_parameters_free_value, publishing_you_tube_value_publishing_parameters_copy_value, publishing_you_tube_value_publishing_parameters_peek_pointer, "p", publishing_you_tube_value_publishing_parameters_collect_value, "p", publishing_you_tube_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingYouTubePublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_you_tube_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingYouTubePublishingParameters), 0, (GInstanceInitFunc) publishing_you_tube_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_you_tube_publishing_parameters_type_id;
		publishing_you_tube_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingYouTubePublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_you_tube_publishing_parameters_type_id__volatile, publishing_you_tube_publishing_parameters_type_id);
	}
	return publishing_you_tube_publishing_parameters_type_id__volatile;
}


gpointer
publishing_you_tube_publishing_parameters_ref (gpointer instance)
{
	PublishingYouTubePublishingParameters * self;
	self = instance;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return instance;
#line 1295 "YouTubePublishing.c"
}


void
publishing_you_tube_publishing_parameters_unref (gpointer instance)
{
	PublishingYouTubePublishingParameters * self;
	self = instance;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		PUBLISHING_YOU_TUBE_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1310 "YouTubePublishing.c"
	}
}


static gpointer
_publishing_rest_support_session_ref0 (gpointer self)
{
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self ? publishing_rest_support_session_ref (self) : NULL;
#line 1320 "YouTubePublishing.c"
}


PublishingYouTubeYouTubeAuthorizer*
publishing_you_tube_you_tube_authorizer_construct (GType object_type,
                                                   PublishingRESTSupportGoogleSession* session,
                                                   SpitPublishingAuthenticator* authenticator)
{
	PublishingYouTubeYouTubeAuthorizer * self = NULL;
	PublishingRESTSupportGoogleSession* _tmp0_;
	SpitPublishingAuthenticator* _tmp1_;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_GOOGLE_SESSION (session), NULL);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_AUTHENTICATOR (authenticator), NULL);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = (PublishingYouTubeYouTubeAuthorizer*) g_object_new (object_type, NULL);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = _publishing_rest_support_session_ref0 (session);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->session = _tmp0_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = _g_object_ref0 (authenticator);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->authenticator);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->authenticator = _tmp1_;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self;
#line 1352 "YouTubePublishing.c"
}


PublishingYouTubeYouTubeAuthorizer*
publishing_you_tube_you_tube_authorizer_new (PublishingRESTSupportGoogleSession* session,
                                             SpitPublishingAuthenticator* authenticator)
{
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return publishing_you_tube_you_tube_authorizer_construct (PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, session, authenticator);
#line 1362 "YouTubePublishing.c"
}


static gboolean
publishing_you_tube_you_tube_authorizer_real_is_authorized_for_domain (GDataAuthorizer* base,
                                                                       GDataAuthorizationDomain* domain)
{
	PublishingYouTubeYouTubeAuthorizer * self;
	gboolean result = FALSE;
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, PublishingYouTubeYouTubeAuthorizer);
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (GDATA_IS_AUTHORIZATION_DOMAIN (domain), FALSE);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = TRUE;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 1380 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_authorizer_real_process_request (GDataAuthorizer* base,
                                                              GDataAuthorizationDomain* domain,
                                                              SoupMessage* message)
{
	PublishingYouTubeYouTubeAuthorizer * self;
	gchar* header = NULL;
	PublishingRESTSupportGoogleSession* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	SoupMessageHeaders* _tmp5_;
	const gchar* _tmp6_;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, PublishingYouTubeYouTubeAuthorizer);
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail ((domain == NULL) || GDATA_IS_AUTHORIZATION_DOMAIN (domain));
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (SOUP_IS_MESSAGE (message));
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (domain == NULL) {
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1408 "YouTubePublishing.c"
	}
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->session;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = publishing_rest_support_google_session_get_access_token (_tmp0_);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = _tmp1_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = g_strdup_printf ("Bearer %s", _tmp2_);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp4_ = _tmp3_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (_tmp2_);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	header = _tmp4_;
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = message->request_headers;
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp6_ = header;
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	soup_message_headers_replace (_tmp5_, "Authorization", _tmp6_);
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (header);
#line 1432 "YouTubePublishing.c"
}


static gboolean
publishing_you_tube_you_tube_authorizer_real_refresh_authorization (GDataAuthorizer* base,
                                                                    GCancellable* cancellable,
                                                                    GError** error)
{
	PublishingYouTubeYouTubeAuthorizer * self;
	gboolean result = FALSE;
	SpitPublishingAuthenticator* _tmp0_;
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, PublishingYouTubeYouTubeAuthorizer);
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail ((cancellable == NULL) || G_IS_CANCELLABLE (cancellable), FALSE);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_authenticator_refresh (_tmp0_);
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = TRUE;
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 1456 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_authorizer_class_init (PublishingYouTubeYouTubeAuthorizerClass * klass)
{
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_authorizer_parent_class = g_type_class_peek_parent (klass);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingYouTubeYouTubeAuthorizerPrivate));
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_you_tube_you_tube_authorizer_finalize;
#line 1469 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_authorizer_gdata_authorizer_interface_init (GDataAuthorizerInterface * iface)
{
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_authorizer_gdata_authorizer_parent_iface = g_type_interface_peek_parent (iface);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->is_authorized_for_domain = (gboolean (*) (GDataAuthorizer *, GDataAuthorizationDomain*)) publishing_you_tube_you_tube_authorizer_real_is_authorized_for_domain;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->process_request = (void (*) (GDataAuthorizer *, GDataAuthorizationDomain*, SoupMessage*)) publishing_you_tube_you_tube_authorizer_real_process_request;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->refresh_authorization = (gboolean (*) (GDataAuthorizer *, GCancellable*, GError**)) publishing_you_tube_you_tube_authorizer_real_refresh_authorization;
#line 1484 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_authorizer_instance_init (PublishingYouTubeYouTubeAuthorizer * self)
{
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv = PUBLISHING_YOU_TUBE_YOU_TUBE_AUTHORIZER_GET_PRIVATE (self);
#line 1493 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_authorizer_finalize (GObject * obj)
{
	PublishingYouTubeYouTubeAuthorizer * self;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_AUTHORIZER, PublishingYouTubeYouTubeAuthorizer);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->authenticator);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_OBJECT_CLASS (publishing_you_tube_you_tube_authorizer_parent_class)->finalize (obj);
#line 1509 "YouTubePublishing.c"
}


GType
publishing_you_tube_you_tube_authorizer_get_type (void)
{
	static volatile gsize publishing_you_tube_you_tube_authorizer_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_you_tube_you_tube_authorizer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingYouTubeYouTubeAuthorizerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_you_tube_you_tube_authorizer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingYouTubeYouTubeAuthorizer), 0, (GInstanceInitFunc) publishing_you_tube_you_tube_authorizer_instance_init, NULL };
		static const GInterfaceInfo gdata_authorizer_info = { (GInterfaceInitFunc) publishing_you_tube_you_tube_authorizer_gdata_authorizer_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_you_tube_you_tube_authorizer_type_id;
		publishing_you_tube_you_tube_authorizer_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingYouTubeYouTubeAuthorizer", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_you_tube_you_tube_authorizer_type_id, gdata_authorizer_get_type (), &gdata_authorizer_info);
		g_once_init_leave (&publishing_you_tube_you_tube_authorizer_type_id__volatile, publishing_you_tube_you_tube_authorizer_type_id);
	}
	return publishing_you_tube_you_tube_authorizer_type_id__volatile;
}


PublishingYouTubeYouTubePublisher*
publishing_you_tube_you_tube_publisher_construct (GType object_type,
                                                  SpitPublishingService* service,
                                                  SpitPublishingPluginHost* host)
{
	PublishingYouTubeYouTubePublisher * self = NULL;
	PublishingYouTubePublishingParameters* _tmp0_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = (PublishingYouTubeYouTubePublisher*) publishing_rest_support_google_publisher_construct (object_type, service, host, "https://gdata.youtube.com/");
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->running = FALSE;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = publishing_you_tube_publishing_parameters_new ();
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_you_tube_publishing_parameters_unref0 (self->priv->publishing_parameters);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->publishing_parameters = _tmp0_;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self;
#line 1566 "YouTubePublishing.c"
}


PublishingYouTubeYouTubePublisher*
publishing_you_tube_you_tube_publisher_new (SpitPublishingService* service,
                                            SpitPublishingPluginHost* host)
{
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return publishing_you_tube_you_tube_publisher_construct (PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, service, host);
#line 1576 "YouTubePublishing.c"
}


static gboolean
publishing_you_tube_you_tube_publisher_real_is_running (PublishingRESTSupportGooglePublisher* base)
{
	PublishingYouTubeYouTubePublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher);
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->running;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = _tmp0_;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 1594 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_real_start (PublishingRESTSupportGooglePublisher* base)
{
	PublishingYouTubeYouTubePublisher * self;
	SpitPublishingAuthenticator* _tmp0_;
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher);
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:141: YouTubePublisher: started.");
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher))) {
#line 144 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1611 "YouTubePublishing.c"
	}
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->running = TRUE;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_authenticator_authenticate (_tmp0_);
#line 1619 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_real_stop (PublishingRESTSupportGooglePublisher* base)
{
	PublishingYouTubeYouTubePublisher * self;
	PublishingRESTSupportGoogleSession* _tmp0_;
	PublishingRESTSupportGoogleSession* _tmp1_;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher);
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:152: YouTubePublisher: stopped.");
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->running = FALSE;
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = _tmp0_;
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_rest_support_session_stop_transactions (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 1643 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_real_on_login_flow_complete (PublishingRESTSupportGooglePublisher* base)
{
	PublishingYouTubeYouTubePublisher * self;
	PublishingYouTubePublishingParameters* _tmp0_;
	PublishingRESTSupportGoogleSession* _tmp1_;
	PublishingRESTSupportGoogleSession* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	PublishingRESTSupportGoogleSession* _tmp5_;
	PublishingRESTSupportGoogleSession* _tmp6_;
	SpitPublishingAuthenticator* _tmp7_;
	PublishingYouTubeYouTubeAuthorizer* _tmp8_;
	PublishingYouTubeYouTubeAuthorizer* _tmp9_;
	GDataYouTubeService* _tmp10_;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher);
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:160: EVENT: OAuth login flow complete.");
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->publishing_parameters;
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = _tmp1_;
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = publishing_rest_support_google_session_get_user_name (_tmp2_);
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp4_ = _tmp3_;
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_parameters_set_user_name (_tmp0_, _tmp4_);
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (_tmp4_);
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp2_);
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp6_ = _tmp5_;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp7_ = self->priv->authenticator;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp8_ = publishing_you_tube_you_tube_authorizer_new (_tmp6_, _tmp7_);
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp9_ = _tmp8_;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp10_ = gdata_youtube_service_new (PUBLISHING_YOU_TUBE_DEVELOPER_KEY, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gdata_authorizer_get_type (), GDataAuthorizer));
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->youtube_service);
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->youtube_service = _tmp10_;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (_tmp9_);
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp6_);
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_do_show_publishing_options_pane (self);
#line 1704 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_on_publishing_options_logout (PublishingYouTubeYouTubePublisher* self)
{
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER (self));
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:170: EVENT: user clicked 'Logout' in the publis" \
"hing options pane.");
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher))) {
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1719 "YouTubePublishing.c"
	}
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_rest_support_google_publisher_do_logout (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 1723 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_on_publishing_options_publish (PublishingYouTubeYouTubePublisher* self)
{
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER (self));
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:179: EVENT: user clicked 'Publish' in the publi" \
"shing options pane.");
#line 181 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher))) {
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1738 "YouTubePublishing.c"
	}
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_do_upload (self);
#line 1742 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_on_upload_status_updated (PublishingYouTubeYouTubePublisher* self,
                                                                 gint file_number,
                                                                 gdouble completed_fraction)
{
	SpitPublishingProgressCallback _tmp0_;
	void* _tmp0__target;
	SpitPublishingProgressCallback _tmp1_;
	void* _tmp1__target;
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER (self));
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:188: EVENT: uploader reports upload %.2f percen" \
"t complete.", 100.0 * completed_fraction);
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->progress_reporter;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0__target = self->priv->progress_reporter_target;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_vala_assert (_tmp0_ != NULL, "progress_reporter != null");
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher))) {
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1769 "YouTubePublishing.c"
	}
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = self->priv->progress_reporter;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1__target = self->priv->progress_reporter_target;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ (file_number, completed_fraction, _tmp1__target);
#line 1777 "YouTubePublishing.c"
}


static void
_publishing_you_tube_you_tube_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                   gint num_photos_published,
                                                                                                                   gpointer self)
{
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_on_upload_complete ((PublishingYouTubeYouTubePublisher*) self, _sender, num_photos_published);
#line 1788 "YouTubePublishing.c"
}


static void
_publishing_you_tube_you_tube_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender,
                                                                                                             GError* err,
                                                                                                             gpointer self)
{
#line 201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_on_upload_error ((PublishingYouTubeYouTubePublisher*) self, _sender, err);
#line 1799 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_on_upload_complete (PublishingYouTubeYouTubePublisher* self,
                                                           PublishingRESTSupportBatchUploader* uploader,
                                                           gint num_published)
{
	guint _tmp0_;
	guint _tmp1_;
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER (self));
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp0_, NULL, FALSE);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_you_tube_you_tube_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_you_tube_you_tube_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:203: EVENT: uploader reports upload complete; %" \
"d items published.", num_published);
#line 205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher))) {
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1828 "YouTubePublishing.c"
	}
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_do_show_success_pane (self);
#line 1832 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_on_upload_error (PublishingYouTubeYouTubePublisher* self,
                                                        PublishingRESTSupportBatchUploader* uploader,
                                                        GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
	const gchar* _tmp2_;
	SpitPublishingPluginHost* _tmp3_;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER (self));
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp0_, NULL, FALSE);
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_you_tube_you_tube_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_you_tube_you_tube_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher))) {
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1861 "YouTubePublishing.c"
	}
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = err->message;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:219: EVENT: uploader reports upload error = '%s" \
"'.", _tmp2_);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp3_, err);
#line 1871 "YouTubePublishing.c"
}


static void
_publishing_you_tube_you_tube_publisher_on_publishing_options_publish_publishing_you_tube_publishing_options_pane_publish (PublishingYouTubePublishingOptionsPane* _sender,
                                                                                                                           gpointer self)
{
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_on_publishing_options_publish ((PublishingYouTubeYouTubePublisher*) self);
#line 1881 "YouTubePublishing.c"
}


static void
_publishing_you_tube_you_tube_publisher_on_publishing_options_logout_publishing_you_tube_publishing_options_pane_logout (PublishingYouTubePublishingOptionsPane* _sender,
                                                                                                                         gpointer self)
{
#line 242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_on_publishing_options_logout ((PublishingYouTubeYouTubePublisher*) self);
#line 1891 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_do_show_publishing_options_pane (PublishingYouTubeYouTubePublisher* self)
{
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	PublishingYouTubePublishingOptionsPane* opts_pane = NULL;
	SpitPublishingAuthenticator* _tmp7_;
	SpitPublishingPluginHost* _tmp8_;
	GtkBuilder* _tmp9_;
	PublishingYouTubePublishingParameters* _tmp10_;
	PublishingYouTubePublishingOptionsPane* _tmp11_;
	PublishingYouTubePublishingOptionsPane* _tmp12_;
	PublishingYouTubePublishingOptionsPane* _tmp13_;
	SpitPublishingPluginHost* _tmp14_;
	PublishingYouTubePublishingOptionsPane* _tmp15_;
	SpitPublishingPluginHost* _tmp16_;
	GError * _inner_error_ = NULL;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER (self));
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:225: ACTION: showing publishing options pane.");
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = gtk_builder_new ();
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	builder = _tmp0_;
#line 1920 "YouTubePublishing.c"
	{
		GtkBuilder* _tmp1_;
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp1_ = builder;
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		gtk_builder_add_from_resource (_tmp1_, PLUGIN_RESOURCE_PATH "/youtube_publishing_options_pane.ui", &_inner_error_);
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1929 "YouTubePublishing.c"
			goto __catch25_g_error;
		}
	}
	goto __finally25;
	__catch25_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
		SpitPublishingPluginHost* _tmp4_;
		GError* _tmp5_;
		GError* _tmp6_;
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		e = _inner_error_;
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_inner_error_ = NULL;
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp2_ = e;
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp3_ = _tmp2_->message;
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_warning ("YouTubePublishing.vala:233: Could not parse UI file! Error: %s.", _tmp3_);
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp4_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp5_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _ ("A file required for publishing is unavailable. Publishing to YouTube c" \
"an’t continue."));
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp6_ = _tmp5_;
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp4_, _tmp6_);
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_error_free0 (_tmp6_);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_error_free0 (e);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (builder);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1968 "YouTubePublishing.c"
	}
	__finally25:
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (builder);
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_clear_error (&_inner_error_);
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 1981 "YouTubePublishing.c"
	}
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp7_ = self->priv->authenticator;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp8_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp9_ = builder;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp10_ = self->priv->publishing_parameters;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp11_ = publishing_you_tube_publishing_options_pane_new (_tmp7_, _tmp8_, _tmp9_, _tmp10_);
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	opts_pane = _tmp11_;
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp12_ = opts_pane;
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_connect_object (_tmp12_, "publish", (GCallback) _publishing_you_tube_you_tube_publisher_on_publishing_options_publish_publishing_you_tube_publishing_options_pane_publish, self, 0);
#line 242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp13_ = opts_pane;
#line 242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_connect_object (_tmp13_, "logout", (GCallback) _publishing_you_tube_you_tube_publisher_on_publishing_options_logout_publishing_you_tube_publishing_options_pane_logout, self, 0);
#line 243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp14_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp15_ = opts_pane;
#line 243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp14_, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp16_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp16_, FALSE);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (opts_pane);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (builder);
#line 2017 "YouTubePublishing.c"
}


static void
_publishing_you_tube_you_tube_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number,
                                                                                                    gdouble fraction_complete,
                                                                                                    gpointer self)
{
#line 269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_on_upload_status_updated ((PublishingYouTubeYouTubePublisher*) self, file_number, fraction_complete);
#line 2028 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_do_upload (PublishingYouTubeYouTubePublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	SpitPublishingPluginHost* _tmp2_;
	void* _tmp3_;
	GDestroyNotify _tmp4_;
	SpitPublishingProgressCallback _tmp5_;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp6_;
	gint _tmp7_;
	SpitPublishingPublishable** _tmp8_;
	gint publishables_length1;
	gint _publishables_size_;
	PublishingYouTubeUploader* uploader = NULL;
	GDataYouTubeService* _tmp9_;
	PublishingRESTSupportGoogleSession* _tmp10_;
	PublishingRESTSupportGoogleSession* _tmp11_;
	SpitPublishingPublishable** _tmp12_;
	gint _tmp12__length1;
	PublishingYouTubePublishingParameters* _tmp13_;
	PublishingYouTubeUploader* _tmp14_;
	PublishingYouTubeUploader* _tmp15_;
	PublishingYouTubeUploader* _tmp16_;
	PublishingYouTubeUploader* _tmp17_;
	PublishingYouTubeUploader* _tmp18_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER (self));
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:249: ACTION: uploading media items to remote se" \
"rver.");
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = spit_publishing_plugin_host_serialize_publishables (_tmp2_, -1, FALSE, &_tmp3_, &_tmp4_);
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter = NULL;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter = _tmp5_;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target = _tmp3_;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp4_;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher))) {
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 2093 "YouTubePublishing.c"
	}
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp6_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp8_ = spit_publishing_plugin_host_get_publishables (_tmp6_, &_tmp7_);
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishables = _tmp8_;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishables_length1 = _tmp7_;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishables_size_ = publishables_length1;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp9_ = self->priv->youtube_service;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp10_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp11_ = _tmp10_;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp12_ = publishables;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp12__length1 = publishables_length1;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp13_ = self->priv->publishing_parameters;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp14_ = publishing_you_tube_uploader_new (_tmp9_, _tmp11_, _tmp12_, _tmp12__length1, _tmp13_);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp15_ = _tmp14_;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp11_);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	uploader = _tmp15_;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp16_ = uploader;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_you_tube_you_tube_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp17_ = uploader;
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_you_tube_you_tube_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp18_ = uploader;
#line 269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_you_tube_you_tube_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2141 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_do_show_success_pane (PublishingYouTubeYouTubePublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER (self));
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:273: ACTION: showing success pane.");
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 2162 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_real_do_logout (PublishingRESTSupportGooglePublisher* base)
{
	PublishingYouTubeYouTubePublisher * self;
	SpitPublishingAuthenticator* _tmp0_;
#line 279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_debug ("YouTubePublishing.vala:280: ACTION: logging out user.");
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (spit_publishing_authenticator_can_logout (_tmp0_)) {
#line 2179 "YouTubePublishing.c"
		SpitPublishingAuthenticator* _tmp1_;
		SpitPublishingAuthenticator* _tmp2_;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp1_ = self->priv->authenticator;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		spit_publishing_authenticator_logout (_tmp1_);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp2_ = self->priv->authenticator;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		spit_publishing_authenticator_authenticate (_tmp2_);
#line 2190 "YouTubePublishing.c"
	}
}


static SpitPublishingAuthenticator*
publishing_you_tube_you_tube_publisher_real_get_authenticator (PublishingRESTSupportGooglePublisher* base)
{
	PublishingYouTubeYouTubePublisher * self;
	SpitPublishingAuthenticator* result = NULL;
	SpitPublishingAuthenticator* _tmp0_;
	SpitPublishingAuthenticator* _tmp5_;
	SpitPublishingAuthenticator* _tmp6_;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher);
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (_tmp0_ == NULL) {
#line 2209 "YouTubePublishing.c"
		PublishingAuthenticatorFactory* _tmp1_;
		PublishingAuthenticatorFactory* _tmp2_;
		SpitPublishingPluginHost* _tmp3_;
		SpitPublishingAuthenticator* _tmp4_;
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp1_ = publishing_authenticator_factory_get_instance ();
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp2_ = _tmp1_;
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp3_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp4_ = spit_publishing_authenticator_factory_create (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR_FACTORY, SpitPublishingAuthenticatorFactory), "youtube", _tmp3_);
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (self->priv->authenticator);
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		self->priv->authenticator = _tmp4_;
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (_tmp2_);
#line 2228 "YouTubePublishing.c"
	}
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = self->priv->authenticator;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = _tmp6_;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 2238 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_class_init (PublishingYouTubeYouTubePublisherClass * klass)
{
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_you_tube_publisher_parent_class = g_type_class_peek_parent (klass);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingYouTubeYouTubePublisherPrivate));
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->is_running = (gboolean (*) (PublishingRESTSupportGooglePublisher *)) publishing_you_tube_you_tube_publisher_real_is_running;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->start = (void (*) (PublishingRESTSupportGooglePublisher *)) publishing_you_tube_you_tube_publisher_real_start;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->stop = (void (*) (PublishingRESTSupportGooglePublisher *)) publishing_you_tube_you_tube_publisher_real_stop;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->on_login_flow_complete = (void (*) (PublishingRESTSupportGooglePublisher *)) publishing_you_tube_you_tube_publisher_real_on_login_flow_complete;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->do_logout = (void (*) (PublishingRESTSupportGooglePublisher *)) publishing_you_tube_you_tube_publisher_real_do_logout;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->get_authenticator = (SpitPublishingAuthenticator* (*) (PublishingRESTSupportGooglePublisher *)) publishing_you_tube_you_tube_publisher_real_get_authenticator;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_you_tube_you_tube_publisher_finalize;
#line 2263 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_instance_init (PublishingYouTubeYouTubePublisher * self)
{
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv = PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_GET_PRIVATE (self);
#line 2272 "YouTubePublishing.c"
}


static void
publishing_you_tube_you_tube_publisher_finalize (GObject * obj)
{
	PublishingYouTubeYouTubePublisher * self;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_you_tube_publishing_parameters_unref0 (self->priv->publishing_parameters);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter = NULL;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->authenticator);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->youtube_service);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_OBJECT_CLASS (publishing_you_tube_you_tube_publisher_parent_class)->finalize (obj);
#line 2298 "YouTubePublishing.c"
}


GType
publishing_you_tube_you_tube_publisher_get_type (void)
{
	static volatile gsize publishing_you_tube_you_tube_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_you_tube_you_tube_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingYouTubeYouTubePublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_you_tube_you_tube_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingYouTubeYouTubePublisher), 0, (GInstanceInitFunc) publishing_you_tube_you_tube_publisher_instance_init, NULL };
		GType publishing_you_tube_you_tube_publisher_type_id;
		publishing_you_tube_you_tube_publisher_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, "PublishingYouTubeYouTubePublisher", &g_define_type_info, 0);
		g_once_init_leave (&publishing_you_tube_you_tube_publisher_type_id__volatile, publishing_you_tube_you_tube_publisher_type_id);
	}
	return publishing_you_tube_you_tube_publisher_type_id__volatile;
}


static gpointer
_publishing_you_tube_publishing_parameters_ref0 (gpointer self)
{
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self ? publishing_you_tube_publishing_parameters_ref (self) : NULL;
#line 2321 "YouTubePublishing.c"
}


static gpointer
_publishing_you_tube_publishing_options_pane_privacy_description_ref0 (gpointer self)
{
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self ? publishing_you_tube_publishing_options_pane_privacy_description_ref (self) : NULL;
#line 2330 "YouTubePublishing.c"
}


static void
_publishing_you_tube_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                   gpointer self)
{
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_options_pane_on_logout_clicked ((PublishingYouTubePublishingOptionsPane*) self);
#line 2340 "YouTubePublishing.c"
}


static void
_publishing_you_tube_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                    gpointer self)
{
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_options_pane_on_publish_clicked ((PublishingYouTubePublishingOptionsPane*) self);
#line 2350 "YouTubePublishing.c"
}


PublishingYouTubePublishingOptionsPane*
publishing_you_tube_publishing_options_pane_construct (GType object_type,
                                                       SpitPublishingAuthenticator* authenticator,
                                                       SpitPublishingPluginHost* host,
                                                       GtkBuilder* builder,
                                                       PublishingYouTubePublishingParameters* publishing_parameters)
{
	PublishingYouTubePublishingOptionsPane * self = NULL;
	gint _tmp0_;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _tmp1_;
	PublishingYouTubePublishingParameters* _tmp2_;
	GtkBuilder* _tmp3_;
	GSList* _tmp4_;
	GSList* _tmp5_;
	GtkBuilder* _tmp6_;
	GObject* _tmp7_;
	GtkLabel* _tmp8_;
	GtkBuilder* _tmp9_;
	GObject* _tmp10_;
	GtkComboBoxText* _tmp11_;
	GtkBuilder* _tmp12_;
	GObject* _tmp13_;
	GtkButton* _tmp14_;
	GtkBuilder* _tmp15_;
	GObject* _tmp16_;
	GtkButton* _tmp17_;
	GtkBuilder* _tmp18_;
	GObject* _tmp19_;
	GtkBox* _tmp20_;
	GtkBuilder* _tmp21_;
	GObject* _tmp22_;
	GtkLabel* _tmp23_;
	GtkLabel* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _tmp33_;
	gint _tmp33__length1;
	GtkComboBoxText* _tmp38_;
	GtkLabel* _tmp39_;
	GtkComboBoxText* _tmp40_;
	GtkButton* _tmp41_;
	GtkButton* _tmp42_;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_AUTHENTICATOR (authenticator), NULL);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS (publishing_parameters), NULL);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = (PublishingYouTubePublishingOptionsPane*) g_object_new (object_type, NULL);
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = publishing_you_tube_publishing_options_pane_create_privacy_descriptions (self, &_tmp0_);
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy_descriptions = (_vala_array_free (self->priv->privacy_descriptions, self->priv->privacy_descriptions_length1, (GDestroyNotify) publishing_you_tube_publishing_options_pane_privacy_description_unref), NULL);
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy_descriptions = _tmp1_;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy_descriptions_length1 = _tmp0_;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->_privacy_descriptions_size_ = self->priv->privacy_descriptions_length1;
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = _publishing_you_tube_publishing_parameters_ref0 (publishing_parameters);
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_you_tube_publishing_parameters_unref0 (self->priv->publishing_parameters);
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->publishing_parameters = _tmp2_;
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = _g_object_ref0 (builder);
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->builder = _tmp3_;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_vala_assert (builder != NULL, "builder != null");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp4_ = gtk_builder_get_objects (builder);
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = _tmp4_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_vala_assert (g_slist_length (_tmp5_) > ((guint) 0), "builder.get_objects().length() > 0");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_slist_free0 (_tmp5_);
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp6_ = self->priv->builder;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp7_ = gtk_builder_get_object (_tmp6_, "login_identity_label");
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp7_) : NULL);
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->login_identity_label);
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->login_identity_label = _tmp8_;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp9_ = self->priv->builder;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp10_ = gtk_builder_get_object (_tmp9_, "privacy_combo");
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp10_) : NULL);
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->privacy_combo);
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy_combo = _tmp11_;
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp12_ = self->priv->builder;
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp13_ = gtk_builder_get_object (_tmp12_, "publish_button");
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, gtk_button_get_type ()) ? ((GtkButton*) _tmp13_) : NULL);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->publish_button = _tmp14_;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp15_ = self->priv->builder;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp16_ = gtk_builder_get_object (_tmp15_, "logout_button");
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, gtk_button_get_type ()) ? ((GtkButton*) _tmp16_) : NULL);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->logout_button = _tmp17_;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp18_ = self->priv->builder;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp19_ = gtk_builder_get_object (_tmp18_, "youtube_pane_widget");
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, gtk_box_get_type ()) ? ((GtkBox*) _tmp19_) : NULL);
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->pane_widget = _tmp20_;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp21_ = self->priv->builder;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp22_ = gtk_builder_get_object (_tmp21_, "privacy_label");
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp22_) : NULL);
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->privacy_label);
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy_label = _tmp23_;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!spit_publishing_authenticator_can_logout (authenticator)) {
#line 2502 "YouTubePublishing.c"
		GtkButton* _tmp24_;
		GtkContainer* _tmp25_;
		GtkContainer* _tmp26_;
		GtkButton* _tmp27_;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp24_ = self->priv->logout_button;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp25_ = gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget));
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp26_ = _tmp25_;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp27_ = self->priv->logout_button;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		gtk_container_remove (_tmp26_, G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_widget_get_type (), GtkWidget));
#line 2517 "YouTubePublishing.c"
	}
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp28_ = self->priv->login_identity_label;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp29_ = publishing_you_tube_publishing_parameters_get_user_name (publishing_parameters);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp30_ = _tmp29_;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp31_ = g_strdup_printf (_ ("You are logged into YouTube as %s."), _tmp30_);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp32_ = _tmp31_;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	gtk_label_set_label (_tmp28_, _tmp32_);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (_tmp32_);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (_tmp30_);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp33_ = self->priv->privacy_descriptions;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp33__length1 = self->priv->privacy_descriptions_length1;
#line 2539 "YouTubePublishing.c"
	{
		PublishingYouTubePublishingOptionsPanePrivacyDescription** desc_collection = NULL;
		gint desc_collection_length1 = 0;
		gint _desc_collection_size_ = 0;
		gint desc_it = 0;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		desc_collection = _tmp33_;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		desc_collection_length1 = _tmp33__length1;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		for (desc_it = 0; desc_it < _tmp33__length1; desc_it = desc_it + 1) {
#line 2551 "YouTubePublishing.c"
			PublishingYouTubePublishingOptionsPanePrivacyDescription* _tmp34_;
			PublishingYouTubePublishingOptionsPanePrivacyDescription* desc = NULL;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_tmp34_ = _publishing_you_tube_publishing_options_pane_privacy_description_ref0 (desc_collection[desc_it]);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			desc = _tmp34_;
#line 2558 "YouTubePublishing.c"
			{
				GtkComboBoxText* _tmp35_;
				PublishingYouTubePublishingOptionsPanePrivacyDescription* _tmp36_;
				const gchar* _tmp37_;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
				_tmp35_ = self->priv->privacy_combo;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
				_tmp36_ = desc;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
				_tmp37_ = _tmp36_->description;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
				gtk_combo_box_text_append_text (_tmp35_, _tmp37_);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
				_publishing_you_tube_publishing_options_pane_privacy_description_unref0 (desc);
#line 2573 "YouTubePublishing.c"
			}
		}
	}
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp38_ = self->priv->privacy_combo;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_combo_box_get_type (), GtkComboBox), (gint) PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PUBLIC);
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp39_ = self->priv->privacy_label;
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp40_ = self->priv->privacy_combo;
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	gtk_label_set_mnemonic_widget (_tmp39_, G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_widget_get_type (), GtkWidget));
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp41_ = self->priv->logout_button;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_connect_object (_tmp41_, "clicked", (GCallback) _publishing_you_tube_publishing_options_pane_on_logout_clicked_gtk_button_clicked, self, 0);
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp42_ = self->priv->publish_button;
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_connect_object (_tmp42_, "clicked", (GCallback) _publishing_you_tube_publishing_options_pane_on_publish_clicked_gtk_button_clicked, self, 0);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self;
#line 2597 "YouTubePublishing.c"
}


PublishingYouTubePublishingOptionsPane*
publishing_you_tube_publishing_options_pane_new (SpitPublishingAuthenticator* authenticator,
                                                 SpitPublishingPluginHost* host,
                                                 GtkBuilder* builder,
                                                 PublishingYouTubePublishingParameters* publishing_parameters)
{
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return publishing_you_tube_publishing_options_pane_construct (PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, authenticator, host, builder, publishing_parameters);
#line 2609 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_on_publish_clicked (PublishingYouTubePublishingOptionsPane* self)
{
	PublishingYouTubePublishingParameters* _tmp0_;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _tmp1_;
	gint _tmp1__length1;
	GtkComboBoxText* _tmp2_;
	PublishingYouTubePublishingOptionsPanePrivacyDescription* _tmp3_;
	PublishingYouTubePrivacySetting _tmp4_;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->publishing_parameters;
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = self->priv->privacy_descriptions;
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1__length1 = self->priv->privacy_descriptions_length1;
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = self->priv->privacy_combo;
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = _tmp1_[gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_combo_box_get_type (), GtkComboBox))];
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp4_ = _tmp3_->privacy_setting;
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_parameters_set_privacy (_tmp0_, _tmp4_);
#line 362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_emit (self, publishing_you_tube_publishing_options_pane_signals[PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0);
#line 2640 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_on_logout_clicked (PublishingYouTubePublishingOptionsPane* self)
{
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_emit (self, publishing_you_tube_publishing_options_pane_signals[PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL], 0);
#line 2651 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_update_publish_button_sensitivity (PublishingYouTubePublishingOptionsPane* self)
{
	GtkButton* _tmp0_;
#line 369 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->publish_button;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 2665 "YouTubePublishing.c"
}


static void
_vala_array_add35 (PublishingYouTubePublishingOptionsPanePrivacyDescription** * array,
                   int* length,
                   int* size,
                   PublishingYouTubePublishingOptionsPanePrivacyDescription* value)
{
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if ((*length) == (*size)) {
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*array = g_renew (PublishingYouTubePublishingOptionsPanePrivacyDescription*, *array, (*size) + 1);
#line 2681 "YouTubePublishing.c"
	}
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*array)[(*length)++] = value;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*array)[*length] = NULL;
#line 2687 "YouTubePublishing.c"
}


static void
_vala_array_add36 (PublishingYouTubePublishingOptionsPanePrivacyDescription** * array,
                   int* length,
                   int* size,
                   PublishingYouTubePublishingOptionsPanePrivacyDescription* value)
{
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if ((*length) == (*size)) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*array = g_renew (PublishingYouTubePublishingOptionsPanePrivacyDescription*, *array, (*size) + 1);
#line 2703 "YouTubePublishing.c"
	}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*array)[(*length)++] = value;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*array)[*length] = NULL;
#line 2709 "YouTubePublishing.c"
}


static void
_vala_array_add37 (PublishingYouTubePublishingOptionsPanePrivacyDescription** * array,
                   int* length,
                   int* size,
                   PublishingYouTubePublishingOptionsPanePrivacyDescription* value)
{
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if ((*length) == (*size)) {
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*array = g_renew (PublishingYouTubePublishingOptionsPanePrivacyDescription*, *array, (*size) + 1);
#line 2725 "YouTubePublishing.c"
	}
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*array)[(*length)++] = value;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	(*array)[*length] = NULL;
#line 2731 "YouTubePublishing.c"
}


static PublishingYouTubePublishingOptionsPanePrivacyDescription**
publishing_you_tube_publishing_options_pane_create_privacy_descriptions (PublishingYouTubePublishingOptionsPane* self,
                                                                         int* result_length1)
{
	PublishingYouTubePublishingOptionsPanePrivacyDescription** result = NULL;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _result_ = NULL;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _tmp0_;
	gint _result__length1;
	gint __result__size_;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _tmp1_;
	gint _tmp1__length1;
	PublishingYouTubePublishingOptionsPanePrivacyDescription* _tmp2_;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _tmp3_;
	gint _tmp3__length1;
	PublishingYouTubePublishingOptionsPanePrivacyDescription* _tmp4_;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _tmp5_;
	gint _tmp5__length1;
	PublishingYouTubePublishingOptionsPanePrivacyDescription* _tmp6_;
	PublishingYouTubePublishingOptionsPanePrivacyDescription** _tmp7_;
	gint _tmp7__length1;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = g_new0 (PublishingYouTubePublishingOptionsPanePrivacyDescription*, 0 + 1);
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_result_ = _tmp0_;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_result__length1 = 0;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	__result__size_ = _result__length1;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = _result_;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1__length1 = _result__length1;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = publishing_you_tube_publishing_options_pane_privacy_description_new (_ ("Public listed"), PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PUBLIC);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_vala_array_add35 (&_result_, &_result__length1, &__result__size_, _tmp2_);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = _result_;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3__length1 = _result__length1;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp4_ = publishing_you_tube_publishing_options_pane_privacy_description_new (_ ("Public unlisted"), PUBLISHING_YOU_TUBE_PRIVACY_SETTING_UNLISTED);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_vala_array_add36 (&_result_, &_result__length1, &__result__size_, _tmp4_);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = _result_;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5__length1 = _result__length1;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp6_ = publishing_you_tube_publishing_options_pane_privacy_description_new (_ ("Private"), PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PRIVATE);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_vala_array_add37 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp7_ = _result_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp7__length1 = _result__length1;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (result_length1) {
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*result_length1 = _tmp7__length1;
#line 2797 "YouTubePublishing.c"
	}
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = _tmp7_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 2803 "YouTubePublishing.c"
}


static GtkWidget*
publishing_you_tube_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base)
{
	PublishingYouTubePublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_;
	GtkBox* _tmp1_;
	GtkWidget* _tmp2_;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPane);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_vala_assert (_tmp0_ != NULL, "pane_widget != null");
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = self->priv->pane_widget;
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = _tmp2_;
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 2829 "YouTubePublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions
publishing_you_tube_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base)
{
	PublishingYouTubePublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPane);
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 2844 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base)
{
	PublishingYouTubePublishingOptionsPane * self;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPane);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_options_pane_update_publish_button_sensitivity (self);
#line 2856 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base)
{
	PublishingYouTubePublishingOptionsPane * self;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPane);
#line 2866 "YouTubePublishing.c"
}


static PublishingYouTubePublishingOptionsPanePrivacyDescription*
publishing_you_tube_publishing_options_pane_privacy_description_construct (GType object_type,
                                                                           const gchar* description,
                                                                           PublishingYouTubePrivacySetting privacy_setting)
{
	PublishingYouTubePublishingOptionsPanePrivacyDescription* self = NULL;
	gchar* _tmp0_;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (description != NULL, NULL);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = (PublishingYouTubePublishingOptionsPanePrivacyDescription*) g_type_create_instance (object_type);
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = g_strdup (description);
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (self->description);
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->description = _tmp0_;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->privacy_setting = privacy_setting;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self;
#line 2891 "YouTubePublishing.c"
}


static PublishingYouTubePublishingOptionsPanePrivacyDescription*
publishing_you_tube_publishing_options_pane_privacy_description_new (const gchar* description,
                                                                     PublishingYouTubePrivacySetting privacy_setting)
{
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return publishing_you_tube_publishing_options_pane_privacy_description_construct (PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, description, privacy_setting);
#line 2901 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_value_privacy_description_init (GValue* value)
{
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	value->data[0].v_pointer = NULL;
#line 2910 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_value_privacy_description_free_value (GValue* value)
{
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (value->data[0].v_pointer) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_publishing_options_pane_privacy_description_unref (value->data[0].v_pointer);
#line 2921 "YouTubePublishing.c"
	}
}


static void
publishing_you_tube_publishing_options_pane_value_privacy_description_copy_value (const GValue* src_value,
                                                                                  GValue* dest_value)
{
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		dest_value->data[0].v_pointer = publishing_you_tube_publishing_options_pane_privacy_description_ref (src_value->data[0].v_pointer);
#line 2934 "YouTubePublishing.c"
	} else {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2938 "YouTubePublishing.c"
	}
}


static gpointer
publishing_you_tube_publishing_options_pane_value_privacy_description_peek_pointer (const GValue* value)
{
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return value->data[0].v_pointer;
#line 2948 "YouTubePublishing.c"
}


static gchar*
publishing_you_tube_publishing_options_pane_value_privacy_description_collect_value (GValue* value,
                                                                                     guint n_collect_values,
                                                                                     GTypeCValue* collect_values,
                                                                                     guint collect_flags)
{
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (collect_values[0].v_pointer) {
#line 2960 "YouTubePublishing.c"
		PublishingYouTubePublishingOptionsPanePrivacyDescription * object;
		object = collect_values[0].v_pointer;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2967 "YouTubePublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2971 "YouTubePublishing.c"
		}
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = publishing_you_tube_publishing_options_pane_privacy_description_ref (object);
#line 2975 "YouTubePublishing.c"
	} else {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2979 "YouTubePublishing.c"
	}
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return NULL;
#line 2983 "YouTubePublishing.c"
}


static gchar*
publishing_you_tube_publishing_options_pane_value_privacy_description_lcopy_value (const GValue* value,
                                                                                   guint n_collect_values,
                                                                                   GTypeCValue* collect_values,
                                                                                   guint collect_flags)
{
	PublishingYouTubePublishingOptionsPanePrivacyDescription ** object_p;
	object_p = collect_values[0].v_pointer;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!object_p) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2999 "YouTubePublishing.c"
	}
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (!value->data[0].v_pointer) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*object_p = NULL;
#line 3005 "YouTubePublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 3009 "YouTubePublishing.c"
	} else {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		*object_p = publishing_you_tube_publishing_options_pane_privacy_description_ref (value->data[0].v_pointer);
#line 3013 "YouTubePublishing.c"
	}
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return NULL;
#line 3017 "YouTubePublishing.c"
}


static GParamSpec*
publishing_you_tube_publishing_options_pane_param_spec_privacy_description (const gchar* name,
                                                                            const gchar* nick,
                                                                            const gchar* blurb,
                                                                            GType object_type,
                                                                            GParamFlags flags)
{
	PublishingYouTubePublishingOptionsPaneParamSpecPrivacyDescription* spec;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION), NULL);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return G_PARAM_SPEC (spec);
#line 3037 "YouTubePublishing.c"
}


static gpointer
publishing_you_tube_publishing_options_pane_value_get_privacy_description (const GValue* value)
{
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION), NULL);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return value->data[0].v_pointer;
#line 3048 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_value_set_privacy_description (GValue* value,
                                                                           gpointer v_object)
{
	PublishingYouTubePublishingOptionsPanePrivacyDescription * old;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION));
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	old = value->data[0].v_pointer;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (v_object) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION));
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_publishing_options_pane_privacy_description_ref (value->data[0].v_pointer);
#line 3071 "YouTubePublishing.c"
	} else {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 3075 "YouTubePublishing.c"
	}
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (old) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_publishing_options_pane_privacy_description_unref (old);
#line 3081 "YouTubePublishing.c"
	}
}


static void
publishing_you_tube_publishing_options_pane_value_take_privacy_description (GValue* value,
                                                                            gpointer v_object)
{
	PublishingYouTubePublishingOptionsPanePrivacyDescription * old;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION));
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	old = value->data[0].v_pointer;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (v_object) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION));
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 3103 "YouTubePublishing.c"
	} else {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 3107 "YouTubePublishing.c"
	}
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (old) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_publishing_options_pane_privacy_description_unref (old);
#line 3113 "YouTubePublishing.c"
	}
}


static void
publishing_you_tube_publishing_options_pane_privacy_description_class_init (PublishingYouTubePublishingOptionsPanePrivacyDescriptionClass * klass)
{
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_options_pane_privacy_description_parent_class = g_type_class_peek_parent (klass);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingYouTubePublishingOptionsPanePrivacyDescriptionClass *) klass)->finalize = publishing_you_tube_publishing_options_pane_privacy_description_finalize;
#line 3125 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_privacy_description_instance_init (PublishingYouTubePublishingOptionsPanePrivacyDescription * self)
{
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->ref_count = 1;
#line 3134 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_privacy_description_finalize (PublishingYouTubePublishingOptionsPanePrivacyDescription * obj)
{
	PublishingYouTubePublishingOptionsPanePrivacyDescription * self;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, PublishingYouTubePublishingOptionsPanePrivacyDescription);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_signal_handlers_destroy (self);
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (self->description);
#line 3148 "YouTubePublishing.c"
}


static GType
publishing_you_tube_publishing_options_pane_privacy_description_get_type (void)
{
	static volatile gsize publishing_you_tube_publishing_options_pane_privacy_description_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_you_tube_publishing_options_pane_privacy_description_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_you_tube_publishing_options_pane_value_privacy_description_init, publishing_you_tube_publishing_options_pane_value_privacy_description_free_value, publishing_you_tube_publishing_options_pane_value_privacy_description_copy_value, publishing_you_tube_publishing_options_pane_value_privacy_description_peek_pointer, "p", publishing_you_tube_publishing_options_pane_value_privacy_description_collect_value, "p", publishing_you_tube_publishing_options_pane_value_privacy_description_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingYouTubePublishingOptionsPanePrivacyDescriptionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_you_tube_publishing_options_pane_privacy_description_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingYouTubePublishingOptionsPanePrivacyDescription), 0, (GInstanceInitFunc) publishing_you_tube_publishing_options_pane_privacy_description_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_you_tube_publishing_options_pane_privacy_description_type_id;
		publishing_you_tube_publishing_options_pane_privacy_description_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingYouTubePublishingOptionsPanePrivacyDescription", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_you_tube_publishing_options_pane_privacy_description_type_id__volatile, publishing_you_tube_publishing_options_pane_privacy_description_type_id);
	}
	return publishing_you_tube_publishing_options_pane_privacy_description_type_id__volatile;
}


static gpointer
publishing_you_tube_publishing_options_pane_privacy_description_ref (gpointer instance)
{
	PublishingYouTubePublishingOptionsPanePrivacyDescription * self;
	self = instance;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return instance;
#line 3177 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_privacy_description_unref (gpointer instance)
{
	PublishingYouTubePublishingOptionsPanePrivacyDescription * self;
	self = instance;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION_GET_CLASS (self)->finalize (self);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 3192 "YouTubePublishing.c"
	}
}


static void
publishing_you_tube_publishing_options_pane_class_init (PublishingYouTubePublishingOptionsPaneClass * klass)
{
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingYouTubePublishingOptionsPanePrivate));
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_you_tube_publishing_options_pane_finalize;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_options_pane_signals[PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL] = g_signal_new ("publish", PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_options_pane_signals[PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL] = g_signal_new ("logout", PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3210 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface)
{
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane *)) publishing_you_tube_publishing_options_pane_real_get_widget;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane *)) publishing_you_tube_publishing_options_pane_real_get_preferred_geometry;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane *)) publishing_you_tube_publishing_options_pane_real_on_pane_installed;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane *)) publishing_you_tube_publishing_options_pane_real_on_pane_uninstalled;
#line 3227 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_instance_init (PublishingYouTubePublishingOptionsPane * self)
{
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv = PUBLISHING_YOU_TUBE_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->pane_widget = NULL;
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy_combo = NULL;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->login_identity_label = NULL;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->publish_button = NULL;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->logout_button = NULL;
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->builder = NULL;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy_label = NULL;
#line 3250 "YouTubePublishing.c"
}


static void
publishing_you_tube_publishing_options_pane_finalize (GObject * obj)
{
	PublishingYouTubePublishingOptionsPane * self;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_YOU_TUBE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingYouTubePublishingOptionsPane);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->privacy_combo);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->login_identity_label);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->privacy_label);
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->privacy_descriptions = (_vala_array_free (self->priv->privacy_descriptions, self->priv->privacy_descriptions_length1, (GDestroyNotify) publishing_you_tube_publishing_options_pane_privacy_description_unref), NULL);
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_you_tube_publishing_parameters_unref0 (self->priv->publishing_parameters);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	G_OBJECT_CLASS (publishing_you_tube_publishing_options_pane_parent_class)->finalize (obj);
#line 3280 "YouTubePublishing.c"
}


GType
publishing_you_tube_publishing_options_pane_get_type (void)
{
	static volatile gsize publishing_you_tube_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_you_tube_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingYouTubePublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_you_tube_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingYouTubePublishingOptionsPane), 0, (GInstanceInitFunc) publishing_you_tube_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_you_tube_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_you_tube_publishing_options_pane_type_id;
		publishing_you_tube_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingYouTubePublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_you_tube_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_you_tube_publishing_options_pane_type_id__volatile, publishing_you_tube_publishing_options_pane_type_id);
	}
	return publishing_you_tube_publishing_options_pane_type_id__volatile;
}


PublishingYouTubeUploadTransaction*
publishing_you_tube_upload_transaction_construct (GType object_type,
                                                  GDataYouTubeService* youtube_service,
                                                  PublishingRESTSupportGoogleSession* session,
                                                  PublishingYouTubePublishingParameters* parameters,
                                                  SpitPublishingPublishable* publishable)
{
	PublishingYouTubeUploadTransaction* self = NULL;
	PublishingRESTSupportGoogleSession* _tmp0_;
	PublishingYouTubePublishingParameters* _tmp1_;
	SpitPublishingPublishable* _tmp2_;
	GDataYouTubeService* _tmp3_;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (GDATA_IS_YOUTUBE_SERVICE (youtube_service), NULL);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_GOOGLE_SESSION (session), NULL);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = (PublishingYouTubeUploadTransaction*) publishing_rest_support_google_publisher_authenticated_transaction_construct (object_type, session, PUBLISHING_YOU_TUBE_UPLOAD_TRANSACTION_ENDPOINT_URL, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_vala_assert (publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession)), "session.is_authenticated()");
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = _publishing_rest_support_session_ref0 (session);
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->session = _tmp0_;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = _publishing_you_tube_publishing_parameters_ref0 (parameters);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_you_tube_publishing_parameters_unref0 (self->priv->parameters);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->parameters = _tmp1_;
#line 413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = _g_object_ref0 (publishable);
#line 413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->publishable);
#line 413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->publishable = _tmp2_;
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = _g_object_ref0 (youtube_service);
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->youtube_service);
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->youtube_service = _tmp3_;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self;
#line 3350 "YouTubePublishing.c"
}


PublishingYouTubeUploadTransaction*
publishing_you_tube_upload_transaction_new (GDataYouTubeService* youtube_service,
                                            PublishingRESTSupportGoogleSession* session,
                                            PublishingYouTubePublishingParameters* parameters,
                                            SpitPublishingPublishable* publishable)
{
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return publishing_you_tube_upload_transaction_construct (PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION, youtube_service, session, parameters, publishable);
#line 3362 "YouTubePublishing.c"
}


static Block1Data*
block1_data_ref (Block1Data* _data1_)
{
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return _data1_;
#line 3373 "YouTubePublishing.c"
}


static void
block1_data_unref (void * _userdata_)
{
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 3384 "YouTubePublishing.c"
		PublishingYouTubeUploadTransaction* self;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		self = _data1_->self;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_main_loop_unref0 (_data1_->loop);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_publishing_rest_support_transaction_unref0 (self);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_slice_free (Block1Data, _data1_);
#line 3394 "YouTubePublishing.c"
	}
}


static void
___lambda4_ (Block1Data* _data1_,
             GObject* obj,
             GAsyncResult* res)
{
	PublishingYouTubeUploadTransaction* self;
	GMainLoop* _tmp2_;
	GError * _inner_error_ = NULL;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = _data1_->self;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail ((obj == NULL) || G_IS_OBJECT (obj));
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_if_fail (G_IS_ASYNC_RESULT (res));
#line 3413 "YouTubePublishing.c"
	{
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_upload_transaction_splice_with_progress_finish (self, res, &_inner_error_);
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3419 "YouTubePublishing.c"
			goto __catch27_g_error;
		}
	}
	goto __finally27;
	__catch27_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_error_ = _inner_error_;
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_inner_error_ = NULL;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp0_ = _error_;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp1_ = _tmp0_->message;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_critical ("YouTubePublishing.vala:451: Failed to upload: %s", _tmp1_);
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_error_free0 (_error_);
#line 3441 "YouTubePublishing.c"
	}
	__finally27:
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_clear_error (&_inner_error_);
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 3452 "YouTubePublishing.c"
	}
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = _data1_->loop;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_main_loop_quit (_tmp2_);
#line 3458 "YouTubePublishing.c"
}


static void
____lambda4__gasync_ready_callback (GObject* source_object,
                                    GAsyncResult* res,
                                    gpointer self)
{
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	___lambda4_ (self, source_object, res);
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	block1_data_unref (self);
#line 3471 "YouTubePublishing.c"
}


static void
publishing_you_tube_upload_transaction_real_execute (PublishingRESTSupportTransaction* base,
                                                     GError** error)
{
	PublishingYouTubeUploadTransaction * self;
	GDataYouTubeVideo* video = NULL;
	GDataYouTubeVideo* _tmp0_;
	gchar* slug = NULL;
	SpitPublishingPublishable* _tmp1_;
	gchar* _tmp2_;
	gchar* title = NULL;
	SpitPublishingPublishable* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	GDataYouTubeVideo* _tmp8_;
	const gchar* _tmp9_;
	GDataYouTubeVideo* _tmp10_;
	PublishingYouTubePublishingParameters* _tmp11_;
	PublishingYouTubePublishingParameters* _tmp12_;
	GFile* file = NULL;
	SpitPublishingPublishable* _tmp18_;
	GFile* _tmp19_;
	GError * _inner_error_ = NULL;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION, PublishingYouTubeUploadTransaction);
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = gdata_youtube_video_new (NULL);
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	video = _tmp0_;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = self->priv->publishable;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = spit_publishing_publishable_get_param_string (_tmp1_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	slug = _tmp2_;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = self->priv->publishable;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp4_ = spit_publishing_publishable_get_publishing_name (_tmp3_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	title = _tmp4_;
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = title;
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (g_strcmp0 (_tmp5_, "") == 0) {
#line 3520 "YouTubePublishing.c"
		SpitPublishingPublishable* _tmp6_;
		gchar* _tmp7_;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp6_ = self->priv->publishable;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp7_ = spit_publishing_publishable_get_param_string (_tmp6_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_free0 (title);
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		title = _tmp7_;
#line 3531 "YouTubePublishing.c"
	}
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp8_ = video;
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp9_ = title;
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	gdata_entry_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gdata_entry_get_type (), GDataEntry), _tmp9_);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp10_ = video;
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp11_ = self->priv->parameters;
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_object_set (_tmp10_, "is-private", publishing_you_tube_publishing_parameters_get_privacy (_tmp11_) == PUBLISHING_YOU_TUBE_PRIVACY_SETTING_PRIVATE, NULL);
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp12_ = self->priv->parameters;
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (publishing_you_tube_publishing_parameters_get_privacy (_tmp12_) == PUBLISHING_YOU_TUBE_PRIVACY_SETTING_UNLISTED) {
#line 3549 "YouTubePublishing.c"
		GDataYouTubeVideo* _tmp13_;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp13_ = video;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		gdata_youtube_video_set_access_control (_tmp13_, "list", GDATA_YOUTUBE_PERMISSION_DENIED);
#line 3555 "YouTubePublishing.c"
	} else {
		GDataYouTubeVideo* _tmp14_;
		gboolean _tmp15_;
		gboolean _tmp16_;
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp14_ = video;
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_object_get (_tmp14_, "is-private", &_tmp15_, NULL);
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp16_ = _tmp15_;
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (!_tmp16_) {
#line 3568 "YouTubePublishing.c"
			GDataYouTubeVideo* _tmp17_;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_tmp17_ = video;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			gdata_youtube_video_set_access_control (_tmp17_, "list", GDATA_YOUTUBE_PERMISSION_ALLOWED);
#line 3574 "YouTubePublishing.c"
		}
	}
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp18_ = self->priv->publishable;
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp19_ = spit_publishing_publishable_get_serialized_file (_tmp18_);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	file = _tmp19_;
#line 3583 "YouTubePublishing.c"
	{
		Block1Data* _data1_;
		GFileInfo* info = NULL;
		GFile* _tmp20_;
		GFileInfo* _tmp21_;
		GDataUploadStream* upload_stream = NULL;
		GDataYouTubeService* _tmp22_;
		GDataYouTubeVideo* _tmp23_;
		const gchar* _tmp24_;
		GFileInfo* _tmp25_;
		const gchar* _tmp26_;
		GDataUploadStream* _tmp27_;
		GFileInputStream* input_stream = NULL;
		GFile* _tmp28_;
		GFileInputStream* _tmp29_;
		GMainLoop* _tmp30_;
		GFileInfo* _tmp31_;
		GFileInputStream* _tmp32_;
		GDataUploadStream* _tmp33_;
		GMainLoop* _tmp34_;
		GDataYouTubeVideo* _tmp35_ = NULL;
		GDataYouTubeService* _tmp36_;
		GDataUploadStream* _tmp37_;
		GDataYouTubeVideo* _tmp38_;
		GDataYouTubeVideo* _tmp39_;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data1_ = g_slice_new0 (Block1Data);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data1_->_ref_count_ = 1;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data1_->self = publishing_rest_support_transaction_ref (self);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp20_ = file;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp21_ = g_file_query_info (_tmp20_, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE "," G_FILE_ATTRIBUTE_STANDARD_SIZE, G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		info = _tmp21_;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			block1_data_unref (_data1_);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_data1_ = NULL;
#line 3627 "YouTubePublishing.c"
			goto __catch26_g_error;
		}
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp22_ = self->priv->youtube_service;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp23_ = video;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp24_ = slug;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp25_ = info;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp26_ = g_file_info_get_content_type (_tmp25_);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp27_ = gdata_youtube_service_upload_video (_tmp22_, _tmp23_, _tmp24_, _tmp26_, NULL, &_inner_error_);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		upload_stream = _tmp27_;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (info);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			block1_data_unref (_data1_);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_data1_ = NULL;
#line 3652 "YouTubePublishing.c"
			goto __catch26_g_error;
		}
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp28_ = file;
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp29_ = g_file_read (_tmp28_, NULL, &_inner_error_);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		input_stream = _tmp29_;
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (upload_stream);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (info);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			block1_data_unref (_data1_);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_data1_ = NULL;
#line 3671 "YouTubePublishing.c"
			goto __catch26_g_error;
		}
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp30_ = g_main_loop_new (NULL, FALSE);
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data1_->loop = _tmp30_;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp31_ = info;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp32_ = input_stream;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp33_ = upload_stream;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		publishing_you_tube_upload_transaction_splice_with_progress (self, _tmp31_, G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, g_input_stream_get_type (), GInputStream), G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, g_output_stream_get_type (), GOutputStream), ____lambda4__gasync_ready_callback, block1_data_ref (_data1_));
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp34_ = _data1_->loop;
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_main_loop_run (_tmp34_);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp36_ = self->priv->youtube_service;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp37_ = upload_stream;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp38_ = gdata_youtube_service_finish_video_upload (_tmp36_, _tmp37_, &_inner_error_);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp35_ = _tmp38_;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (input_stream);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (upload_stream);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (info);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			block1_data_unref (_data1_);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_data1_ = NULL;
#line 3710 "YouTubePublishing.c"
			goto __catch26_g_error;
		}
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp39_ = _tmp35_;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp35_ = NULL;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (video);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		video = _tmp39_;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (_tmp35_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (input_stream);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (upload_stream);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_object_unref0 (info);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		block1_data_unref (_data1_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data1_ = NULL;
#line 3733 "YouTubePublishing.c"
	}
	goto __finally26;
	__catch26_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp40_;
		const gchar* _tmp41_;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_error_ = _inner_error_;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_inner_error_ = NULL;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp40_ = _error_;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_tmp41_ = _tmp40_->message;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_critical ("YouTubePublishing.vala:458: Upload failed: %s", _tmp41_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_g_error_free0 (_error_);
#line 3753 "YouTubePublishing.c"
	}
	__finally26:
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (file);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_free0 (title);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_free0 (slug);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (video);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			return;
#line 3772 "YouTubePublishing.c"
		} else {
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (file);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_free0 (title);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_free0 (slug);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			_g_object_unref0 (video);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			g_clear_error (&_inner_error_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			return;
#line 3788 "YouTubePublishing.c"
		}
	}
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (file);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (title);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_free0 (slug);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (video);
#line 3799 "YouTubePublishing.c"
}


static void
publishing_you_tube_upload_transaction_splice_with_progress_data_free (gpointer _data)
{
	PublishingYouTubeUploadTransactionSpliceWithProgressData* _data_;
	_data_ = _data;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (_data_->info);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (_data_->input);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (_data_->output);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_transaction_unref0 (_data_->self);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_slice_free (PublishingYouTubeUploadTransactionSpliceWithProgressData, _data_);
#line 3818 "YouTubePublishing.c"
}


static void
publishing_you_tube_upload_transaction_splice_with_progress_async_ready_wrapper (GObject *source_object,
                                                                                 GAsyncResult *res,
                                                                                 void *user_data)
{
	PublishingYouTubeUploadTransactionSpliceWithProgressData* _task_data_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_task_data_ = g_task_get_task_data (G_TASK (res));
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (_task_data_->_callback_ != NULL) {
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_task_data_->_callback_ (source_object, res, user_data);
#line 3834 "YouTubePublishing.c"
	}
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_task_data_->_task_complete_ = TRUE;
#line 3838 "YouTubePublishing.c"
}


static gpointer
_publishing_rest_support_transaction_ref0 (gpointer self)
{
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self ? publishing_rest_support_transaction_ref (self) : NULL;
#line 3847 "YouTubePublishing.c"
}


static void
publishing_you_tube_upload_transaction_splice_with_progress (PublishingYouTubeUploadTransaction* self,
                                                             GFileInfo* info,
                                                             GInputStream* input,
                                                             GOutputStream* output,
                                                             GAsyncReadyCallback _callback_,
                                                             gpointer _user_data_)
{
	PublishingYouTubeUploadTransactionSpliceWithProgressData* _data_;
	PublishingYouTubeUploadTransaction* _tmp0_;
	GFileInfo* _tmp1_;
	GInputStream* _tmp2_;
	GOutputStream* _tmp3_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_ = g_slice_new0 (PublishingYouTubeUploadTransactionSpliceWithProgressData);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->_callback_ = _callback_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->_async_result = g_task_new (NULL, NULL, publishing_you_tube_upload_transaction_splice_with_progress_async_ready_wrapper, _user_data_);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (_callback_ == NULL) {
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_task_complete_ = TRUE;
#line 3874 "YouTubePublishing.c"
	}
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_task_set_task_data (_data_->_async_result, _data_, publishing_you_tube_upload_transaction_splice_with_progress_data_free);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = _publishing_rest_support_transaction_ref0 (self);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->self = _tmp0_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = _g_object_ref0 (info);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (_data_->info);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->info = _tmp1_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = _g_object_ref0 (input);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (_data_->input);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->input = _tmp2_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = _g_object_ref0 (output);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (_data_->output);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->output = _tmp3_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_upload_transaction_splice_with_progress_co (_data_);
#line 3902 "YouTubePublishing.c"
}


static void
publishing_you_tube_upload_transaction_splice_with_progress_finish (PublishingYouTubeUploadTransaction* self,
                                                                    GAsyncResult* _res_,
                                                                    GError** error)
{
	PublishingYouTubeUploadTransactionSpliceWithProgressData* _data_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (NULL == _data_) {
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return;
#line 3918 "YouTubePublishing.c"
	}
}


static void
publishing_you_tube_upload_transaction_splice_with_progress_ready (GObject* source_object,
                                                                   GAsyncResult* _res_,
                                                                   gpointer _user_data_)
{
	PublishingYouTubeUploadTransactionSpliceWithProgressData* _data_;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_ = _user_data_;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->_source_object_ = source_object;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->_res_ = _res_;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->_task_complete_ = TRUE;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_upload_transaction_splice_with_progress_co (_data_);
#line 3939 "YouTubePublishing.c"
}


static gboolean
publishing_you_tube_upload_transaction_splice_with_progress_co (PublishingYouTubeUploadTransactionSpliceWithProgressData* _data_)
{
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	switch (_data_->_state_) {
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		case 0:
#line 3950 "YouTubePublishing.c"
		goto _state_0;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		case 1:
#line 3954 "YouTubePublishing.c"
		goto _state_1;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		case 2:
#line 3958 "YouTubePublishing.c"
		goto _state_2;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		case 3:
#line 3962 "YouTubePublishing.c"
		goto _state_3;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		case 4:
#line 3966 "YouTubePublishing.c"
		goto _state_4;
		default:
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_assert_not_reached ();
#line 3971 "YouTubePublishing.c"
	}
	_state_0:
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->total_bytes = g_file_info_get_size (_data_->info);
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->_tmp0_ = _data_->total_bytes;
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->bytes_to_write = _data_->_tmp0_;
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	while (TRUE) {
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_tmp1_ = _data_->bytes_to_write;
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (!(_data_->_tmp1_ > ((gint64) 0))) {
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			break;
#line 3988 "YouTubePublishing.c"
		}
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_state_ = 1;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_input_stream_read_async (_data_->input, _data_->buffer, (gsize) 8192, G_PRIORITY_DEFAULT, NULL, publishing_you_tube_upload_transaction_splice_with_progress_ready, _data_);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return FALSE;
#line 3996 "YouTubePublishing.c"
		_state_1:
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->bytes_read = g_input_stream_read_finish (_data_->input, _data_->_res_, &_data_->_inner_error_);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			g_object_unref (_data_->_async_result);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			return FALSE;
#line 4008 "YouTubePublishing.c"
		}
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_tmp2_ = _data_->bytes_read;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (_data_->_tmp2_ == ((gssize) 0)) {
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			break;
#line 4016 "YouTubePublishing.c"
		}
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_tmp3_ = _data_->bytes_read;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_state_ = 2;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_output_stream_write_async (_data_->output, _data_->buffer + 0, (gsize) (((gint) _data_->_tmp3_) - 0), G_PRIORITY_DEFAULT, NULL, publishing_you_tube_upload_transaction_splice_with_progress_ready, _data_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return FALSE;
#line 4026 "YouTubePublishing.c"
		_state_2:
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->bytes_written = g_output_stream_write_finish (_data_->output, _data_->_res_, &_data_->_inner_error_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			g_object_unref (_data_->_async_result);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			return FALSE;
#line 4038 "YouTubePublishing.c"
		}
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_tmp4_ = _data_->bytes_to_write;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_tmp5_ = _data_->bytes_written;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->bytes_to_write = _data_->_tmp4_ - _data_->_tmp5_;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_tmp6_ = _data_->total_bytes;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_tmp7_ = _data_->bytes_to_write;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		_data_->_tmp8_ = _data_->total_bytes;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "chunk-transmitted", (gint) (_data_->_tmp6_ - _data_->_tmp7_), (gint) _data_->_tmp8_);
#line 4054 "YouTubePublishing.c"
	}
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->_state_ = 3;
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_output_stream_close_async (_data_->output, G_PRIORITY_DEFAULT, NULL, publishing_you_tube_upload_transaction_splice_with_progress_ready, _data_);
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return FALSE;
#line 4062 "YouTubePublishing.c"
	_state_3:
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_output_stream_close_finish (_data_->output, _data_->_res_, &_data_->_inner_error_);
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_object_unref (_data_->_async_result);
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return FALSE;
#line 4074 "YouTubePublishing.c"
	}
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_data_->_state_ = 4;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_input_stream_close_async (_data_->input, G_PRIORITY_DEFAULT, NULL, publishing_you_tube_upload_transaction_splice_with_progress_ready, _data_);
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return FALSE;
#line 4082 "YouTubePublishing.c"
	_state_4:
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_input_stream_close_finish (_data_->input, _data_->_res_, &_data_->_inner_error_);
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		g_object_unref (_data_->_async_result);
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		return FALSE;
#line 4094 "YouTubePublishing.c"
	}
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	if (_data_->_state_ != 0) {
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 4104 "YouTubePublishing.c"
		}
	}
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_object_unref (_data_->_async_result);
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return FALSE;
#line 4111 "YouTubePublishing.c"
}


static void
publishing_you_tube_upload_transaction_class_init (PublishingYouTubeUploadTransactionClass * klass)
{
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_upload_transaction_parent_class = g_type_class_peek_parent (klass);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_you_tube_upload_transaction_finalize;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingYouTubeUploadTransactionPrivate));
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = (void (*) (PublishingRESTSupportTransaction *, GError**)) publishing_you_tube_upload_transaction_real_execute;
#line 4126 "YouTubePublishing.c"
}


static void
publishing_you_tube_upload_transaction_instance_init (PublishingYouTubeUploadTransaction * self)
{
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv = PUBLISHING_YOU_TUBE_UPLOAD_TRANSACTION_GET_PRIVATE (self);
#line 4135 "YouTubePublishing.c"
}


static void
publishing_you_tube_upload_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingYouTubeUploadTransaction * self;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_YOU_TUBE_TYPE_UPLOAD_TRANSACTION, PublishingYouTubeUploadTransaction);
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_you_tube_publishing_parameters_unref0 (self->priv->parameters);
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->publishable);
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->youtube_service);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_you_tube_upload_transaction_parent_class)->finalize (obj);
#line 4155 "YouTubePublishing.c"
}


GType
publishing_you_tube_upload_transaction_get_type (void)
{
	static volatile gsize publishing_you_tube_upload_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_you_tube_upload_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingYouTubeUploadTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_you_tube_upload_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingYouTubeUploadTransaction), 0, (GInstanceInitFunc) publishing_you_tube_upload_transaction_instance_init, NULL };
		GType publishing_you_tube_upload_transaction_type_id;
		publishing_you_tube_upload_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_GOOGLE_PUBLISHER_TYPE_AUTHENTICATED_TRANSACTION, "PublishingYouTubeUploadTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_you_tube_upload_transaction_type_id__volatile, publishing_you_tube_upload_transaction_type_id);
	}
	return publishing_you_tube_upload_transaction_type_id__volatile;
}


PublishingYouTubeUploader*
publishing_you_tube_uploader_construct (GType object_type,
                                        GDataYouTubeService* youtube_service,
                                        PublishingRESTSupportGoogleSession* session,
                                        SpitPublishingPublishable** publishables,
                                        int publishables_length1,
                                        PublishingYouTubePublishingParameters* parameters)
{
	PublishingYouTubeUploader* self = NULL;
	PublishingYouTubePublishingParameters* _tmp0_;
	GDataYouTubeService* _tmp1_;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (GDATA_IS_YOUTUBE_SERVICE (youtube_service), NULL);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_GOOGLE_SESSION (session), NULL);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (PUBLISHING_YOU_TUBE_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = (PublishingYouTubeUploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), publishables, publishables_length1);
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = _publishing_you_tube_publishing_parameters_ref0 (parameters);
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_you_tube_publishing_parameters_unref0 (self->priv->parameters);
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->parameters = _tmp0_;
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = _g_object_ref0 (youtube_service);
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->youtube_service);
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv->youtube_service = _tmp1_;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return self;
#line 4206 "YouTubePublishing.c"
}


PublishingYouTubeUploader*
publishing_you_tube_uploader_new (GDataYouTubeService* youtube_service,
                                  PublishingRESTSupportGoogleSession* session,
                                  SpitPublishingPublishable** publishables,
                                  int publishables_length1,
                                  PublishingYouTubePublishingParameters* parameters)
{
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return publishing_you_tube_uploader_construct (PUBLISHING_YOU_TUBE_TYPE_UPLOADER, youtube_service, session, publishables, publishables_length1, parameters);
#line 4219 "YouTubePublishing.c"
}


static PublishingRESTSupportTransaction*
publishing_you_tube_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base,
                                                      SpitPublishingPublishable* publishable)
{
	PublishingYouTubeUploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	GDataYouTubeService* _tmp0_;
	PublishingRESTSupportSession* _tmp1_;
	PublishingRESTSupportGoogleSession* _tmp2_;
	PublishingYouTubePublishingParameters* _tmp3_;
	SpitPublishingPublishable* _tmp4_;
	SpitPublishingPublishable* _tmp5_;
	PublishingYouTubeUploadTransaction* _tmp6_;
	PublishingRESTSupportTransaction* _tmp7_;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_YOU_TUBE_TYPE_UPLOADER, PublishingYouTubeUploader);
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp0_ = self->priv->youtube_service;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp1_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_SESSION, PublishingRESTSupportGoogleSession);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp3_ = self->priv->parameters;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp4_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp5_ = _tmp4_;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp6_ = publishing_you_tube_upload_transaction_new (_tmp0_, _tmp2_, _tmp3_, _tmp5_);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_tmp7_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (_tmp5_);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp2_);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	result = _tmp7_;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	return result;
#line 4265 "YouTubePublishing.c"
}


static void
publishing_you_tube_uploader_class_init (PublishingYouTubeUploaderClass * klass)
{
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	publishing_you_tube_uploader_parent_class = g_type_class_peek_parent (klass);
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_you_tube_uploader_finalize;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingYouTubeUploaderPrivate));
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = (PublishingRESTSupportTransaction* (*) (PublishingRESTSupportBatchUploader *, SpitPublishingPublishable*)) publishing_you_tube_uploader_real_create_transaction;
#line 4280 "YouTubePublishing.c"
}


static void
publishing_you_tube_uploader_instance_init (PublishingYouTubeUploader * self)
{
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self->priv = PUBLISHING_YOU_TUBE_UPLOADER_GET_PRIVATE (self);
#line 4289 "YouTubePublishing.c"
}


static void
publishing_you_tube_uploader_finalize (PublishingRESTSupportBatchUploader * obj)
{
	PublishingYouTubeUploader * self;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_YOU_TUBE_TYPE_UPLOADER, PublishingYouTubeUploader);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_publishing_you_tube_publishing_parameters_unref0 (self->priv->parameters);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	_g_object_unref0 (self->priv->youtube_service);
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/YouTubePublishing.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_you_tube_uploader_parent_class)->finalize (obj);
#line 4305 "YouTubePublishing.c"
}


GType
publishing_you_tube_uploader_get_type (void)
{
	static volatile gsize publishing_you_tube_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_you_tube_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingYouTubeUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_you_tube_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingYouTubeUploader), 0, (GInstanceInitFunc) publishing_you_tube_uploader_instance_init, NULL };
		GType publishing_you_tube_uploader_type_id;
		publishing_you_tube_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingYouTubeUploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_you_tube_uploader_type_id__volatile, publishing_you_tube_uploader_type_id);
	}
	return publishing_you_tube_uploader_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



